#[repr(transparent)]pub struct ArkWeb_BlanklessErrorCode(pub c_int);Available on crate features
api-11 and api-12 and api-20 only.Expand description
Defines an enum for the error codes of the white screen optimization solution.
Available since API-level: 20
Tuple Fields
0: c_intImplementations
Sourceimpl ArkWeb_BlanklessErrorCode
impl ArkWeb_BlanklessErrorCode
Sourcepub const ARKWEB_BLANKLESS_SUCCESS: ArkWeb_BlanklessErrorCode
pub const ARKWEB_BLANKLESS_SUCCESS: ArkWeb_BlanklessErrorCode
The operation is successful.
Sourcepub const ARKWEB_BLANKLESS_ERR_UNKNOWN: ArkWeb_BlanklessErrorCode
pub const ARKWEB_BLANKLESS_ERR_UNKNOWN: ArkWeb_BlanklessErrorCode
Unidentified error.
Sourcepub const ARKWEB_BLANKLESS_ERR_INVALID_ARGS: ArkWeb_BlanklessErrorCode
pub const ARKWEB_BLANKLESS_ERR_INVALID_ARGS: ArkWeb_BlanklessErrorCode
Invalid parameter.
Sourcepub const ARKWEB_BLANKLESS_ERR_CONTROLLER_NOT_INITED: ArkWeb_BlanklessErrorCode
pub const ARKWEB_BLANKLESS_ERR_CONTROLLER_NOT_INITED: ArkWeb_BlanklessErrorCode
The web controller is not bound to a component.
Sourcepub const ARKWEB_BLANKLESS_ERR_KEY_NOT_MATCH: ArkWeb_BlanklessErrorCode
pub const ARKWEB_BLANKLESS_ERR_KEY_NOT_MATCH: ArkWeb_BlanklessErrorCode
The key value is not matched. The OH_NativeArkWeb_SetBlanklessLoadingWithKey and OH_NativeArkWeb_GetBlanklessInfoWithKey APIs must be used in pair and use the same key value.
Sourcepub const ARKWEB_BLANKLESS_ERR_SIGNIFICANT_CHANGE: ArkWeb_BlanklessErrorCode
pub const ARKWEB_BLANKLESS_ERR_SIGNIFICANT_CHANGE: ArkWeb_BlanklessErrorCode
If the similarity is low, the system determines that the change is too large. As a result, the OH_NativeArkWeb_SetBlanklessLoadingWithKey API fails to enable frame interpolation.
Sourcepub const ARKWEB_BLANKLESS_ERR_DEVICE_NOT_SUPPORT: ArkWeb_BlanklessErrorCode
pub const ARKWEB_BLANKLESS_ERR_DEVICE_NOT_SUPPORT: ArkWeb_BlanklessErrorCode
The device does not support this feature.