#[repr(transparent)]pub struct ArkWeb_NetError(pub c_int);api-11 and api-12 only.Tuple Fields
0: c_intImplementations
Sourceimpl ArkWeb_NetError
impl ArkWeb_NetError
Sourcepub const ARKWEB_NET_OK: ArkWeb_NetError
pub const ARKWEB_NET_OK: ArkWeb_NetError
Normal.
Sourcepub const ARKWEB_ERR_IO_PENDING: ArkWeb_NetError
pub const ARKWEB_ERR_IO_PENDING: ArkWeb_NetError
An asynchronous IO operation is not yet complete. This usually does not indicate a fatal error. Typically this error will be generated as a notification to wait for some external notification that the IO operation finally completed.
Sourcepub const ARKWEB_ERR_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_FAILED: ArkWeb_NetError
A generic failure occurred.
Sourcepub const ARKWEB_ERR_ABORTED: ArkWeb_NetError
pub const ARKWEB_ERR_ABORTED: ArkWeb_NetError
An operation was aborted.
Sourcepub const ARKWEB_ERR_INVALID_ARGUMENT: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_ARGUMENT: ArkWeb_NetError
An argument to the function is incorrect.
Sourcepub const ARKWEB_ERR_INVALID_HANDLE: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_HANDLE: ArkWeb_NetError
The handle or file descriptor is invalid.
Sourcepub const ARKWEB_ERR_FILE_NOT_FOUND: ArkWeb_NetError
pub const ARKWEB_ERR_FILE_NOT_FOUND: ArkWeb_NetError
The file or directory cannot be found.
Sourcepub const ARKWEB_ERR_TIMED_OUT: ArkWeb_NetError
pub const ARKWEB_ERR_TIMED_OUT: ArkWeb_NetError
An operation timed out.
Sourcepub const ARKWEB_ERR_FILE_TOO_LARGE: ArkWeb_NetError
pub const ARKWEB_ERR_FILE_TOO_LARGE: ArkWeb_NetError
The file is too large.
Sourcepub const ARKWEB_ERR_UNEXPECTED: ArkWeb_NetError
pub const ARKWEB_ERR_UNEXPECTED: ArkWeb_NetError
An unexpected error. This may be caused by a programming mistake or an invalid assumption.
Sourcepub const ARKWEB_ERR_ACCESS_DENIED: ArkWeb_NetError
pub const ARKWEB_ERR_ACCESS_DENIED: ArkWeb_NetError
Permission to access a resource, other than the network, was denied.
Sourcepub const ARKWEB_ERR_NOT_IMPLEMENTED: ArkWeb_NetError
pub const ARKWEB_ERR_NOT_IMPLEMENTED: ArkWeb_NetError
The operation failed because of unimplemented functionality.
Sourcepub const ARKWEB_ERR_INSUFFICIENT_RESOURCES: ArkWeb_NetError
pub const ARKWEB_ERR_INSUFFICIENT_RESOURCES: ArkWeb_NetError
There were not enough resources to complete the operation.
Sourcepub const ARKWEB_ERR_OUT_OF_MEMORY: ArkWeb_NetError
pub const ARKWEB_ERR_OUT_OF_MEMORY: ArkWeb_NetError
Memory allocation failed.
Sourcepub const ARKWEB_ERR_UPLOAD_FILE_CHANGED: ArkWeb_NetError
pub const ARKWEB_ERR_UPLOAD_FILE_CHANGED: ArkWeb_NetError
The file upload failed because the file’s modification time was different from the expectation.
Sourcepub const ARKWEB_ERR_SOCKET_NOT_CONNECTED: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKET_NOT_CONNECTED: ArkWeb_NetError
The socket is not connected.
Sourcepub const ARKWEB_ERR_FILE_EXISTS: ArkWeb_NetError
pub const ARKWEB_ERR_FILE_EXISTS: ArkWeb_NetError
The file already exists.
Sourcepub const ARKWEB_ERR_FILE_PATH_TOO_LONG: ArkWeb_NetError
pub const ARKWEB_ERR_FILE_PATH_TOO_LONG: ArkWeb_NetError
The path or file name is too long.
Sourcepub const ARKWEB_ERR_FILE_NO_SPACE: ArkWeb_NetError
pub const ARKWEB_ERR_FILE_NO_SPACE: ArkWeb_NetError
Not enough room left on the disk.
Sourcepub const ARKWEB_ERR_FILE_VIRUS_INFECTED: ArkWeb_NetError
pub const ARKWEB_ERR_FILE_VIRUS_INFECTED: ArkWeb_NetError
The file has a virus.
Sourcepub const ARKWEB_ERR_BLOCKED_BY_CLIENT: ArkWeb_NetError
pub const ARKWEB_ERR_BLOCKED_BY_CLIENT: ArkWeb_NetError
The client chose to block the request.
Sourcepub const ARKWEB_ERR_NETWORK_CHANGED: ArkWeb_NetError
pub const ARKWEB_ERR_NETWORK_CHANGED: ArkWeb_NetError
The network changed.
Sourcepub const ARKWEB_ERR_BLOCKED_BY_ADMINISTRATOR: ArkWeb_NetError
pub const ARKWEB_ERR_BLOCKED_BY_ADMINISTRATOR: ArkWeb_NetError
The request was blocked by the URL block list configured by the domain administrator.
Sourcepub const ARKWEB_ERR_SOCKET_CONNECTED: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKET_CONNECTED: ArkWeb_NetError
The socket is already connected.
Sourcepub const ARKWEB_ERR_UPLOAD_STREAM_REWIND_NOT_SUPPORTED: ArkWeb_NetError
pub const ARKWEB_ERR_UPLOAD_STREAM_REWIND_NOT_SUPPORTED: ArkWeb_NetError
The upload failed because the upload stream needed to be re-read, due to a retry or a redirect, but the upload stream doesn’t support that operation.
Sourcepub const ARKWEB_ERR_CONTEXT_SHUT_DOWN: ArkWeb_NetError
pub const ARKWEB_ERR_CONTEXT_SHUT_DOWN: ArkWeb_NetError
The request failed because the URLRequestContext is shutting down, or has been shut down.
Sourcepub const ARKWEB_ERR_BLOCKED_BY_RESPONSE: ArkWeb_NetError
pub const ARKWEB_ERR_BLOCKED_BY_RESPONSE: ArkWeb_NetError
The request failed because the response was delivered along with requirements which are not met (‘X-Frame-Options’ and ‘Content-Security-Policy’ ancestor checks and ‘Cross-Origin-Resource-Policy’ for instance).
Sourcepub const ARKWEB_ERR_CLEARTEXT_NOT_PERMITTED: ArkWeb_NetError
pub const ARKWEB_ERR_CLEARTEXT_NOT_PERMITTED: ArkWeb_NetError
The request was blocked by system policy disallowing some or all cleartext requests.
Sourcepub const ARKWEB_ERR_BLOCKED_BY_CSP: ArkWeb_NetError
pub const ARKWEB_ERR_BLOCKED_BY_CSP: ArkWeb_NetError
The request was blocked by a Content Security Policy.
Sourcepub const ARKWEB_ERR_H2_OR_QUIC_REQUIRED: ArkWeb_NetError
pub const ARKWEB_ERR_H2_OR_QUIC_REQUIRED: ArkWeb_NetError
The request was blocked because of no H/2 or QUIC session.
Sourcepub const ARKWEB_ERR_BLOCKED_BY_ORB: ArkWeb_NetError
pub const ARKWEB_ERR_BLOCKED_BY_ORB: ArkWeb_NetError
The request was blocked by CORB or ORB.
Sourcepub const ARKWEB_ERR_CONNECTION_CLOSED: ArkWeb_NetError
pub const ARKWEB_ERR_CONNECTION_CLOSED: ArkWeb_NetError
A connection was closed (corresponding to a TCP FIN).
Sourcepub const ARKWEB_ERR_CONNECTION_RESET: ArkWeb_NetError
pub const ARKWEB_ERR_CONNECTION_RESET: ArkWeb_NetError
A connection was reset (corresponding to a TCP RST).
Sourcepub const ARKWEB_ERR_CONNECTION_REFUSED: ArkWeb_NetError
pub const ARKWEB_ERR_CONNECTION_REFUSED: ArkWeb_NetError
A connection attempt was refused.
Sourcepub const ARKWEB_ERR_CONNECTION_ABORTED: ArkWeb_NetError
pub const ARKWEB_ERR_CONNECTION_ABORTED: ArkWeb_NetError
A connection timed out as a result of not receiving an ACK for data sent. This can include a FIN packet that did not get ACK’d.
Sourcepub const ARKWEB_ERR_CONNECTION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_CONNECTION_FAILED: ArkWeb_NetError
A connection attempt failed.
Sourcepub const ARKWEB_ERR_NAME_NOT_RESOLVED: ArkWeb_NetError
pub const ARKWEB_ERR_NAME_NOT_RESOLVED: ArkWeb_NetError
The host name could not be resolved.
Sourcepub const ARKWEB_ERR_INTERNET_DISCONNECTED: ArkWeb_NetError
pub const ARKWEB_ERR_INTERNET_DISCONNECTED: ArkWeb_NetError
The Internet connection has been lost.
Sourcepub const ARKWEB_ERR_SSL_PROTOCOL_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_PROTOCOL_ERROR: ArkWeb_NetError
An SSL protocol error occurred.
Sourcepub const ARKWEB_ERR_ADDRESS_INVALID: ArkWeb_NetError
pub const ARKWEB_ERR_ADDRESS_INVALID: ArkWeb_NetError
The IP address or port number is invalid (e.g., cannot connect to the IP address 0 or the port 0).
Sourcepub const ARKWEB_ERR_ADDRESS_UNREACHABLE: ArkWeb_NetError
pub const ARKWEB_ERR_ADDRESS_UNREACHABLE: ArkWeb_NetError
The IP address is unreachable. This usually means that there is no route to the specified host or network.
Sourcepub const ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_NEEDED: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_NEEDED: ArkWeb_NetError
The server requested a client certificate for SSL client authentication.
Sourcepub const ARKWEB_ERR_TUNNEL_CONNECTION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_TUNNEL_CONNECTION_FAILED: ArkWeb_NetError
A tunnel connection through the proxy could not be established.
Sourcepub const ARKWEB_ERR_NO_SSL_VERSIONS_ENABLED: ArkWeb_NetError
pub const ARKWEB_ERR_NO_SSL_VERSIONS_ENABLED: ArkWeb_NetError
No SSL protocol versions are enabled.
Sourcepub const ARKWEB_ERR_SSL_VERSION_OR_CIPHER_MISMATCH: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_VERSION_OR_CIPHER_MISMATCH: ArkWeb_NetError
The client and server don’t support a common SSL protocol version or cipher suite.
Sourcepub const ARKWEB_ERR_SSL_RENEGOTIATION_REQUESTED: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_RENEGOTIATION_REQUESTED: ArkWeb_NetError
The server requested a renegotiation (rehandshake).
Sourcepub const ARKWEB_ERR_PROXY_AUTH_UNSUPPORTED: ArkWeb_NetError
pub const ARKWEB_ERR_PROXY_AUTH_UNSUPPORTED: ArkWeb_NetError
The proxy requested authentication (for tunnel establishment, with an unsupported method.
Sourcepub const ARKWEB_ERR_BAD_SSL_CLIENT_AUTH_CERT: ArkWeb_NetError
pub const ARKWEB_ERR_BAD_SSL_CLIENT_AUTH_CERT: ArkWeb_NetError
The SSL handshake failed because of a bad or missing client certificate.
Sourcepub const ARKWEB_ERR_CONNECTION_TIMED_OUT: ArkWeb_NetError
pub const ARKWEB_ERR_CONNECTION_TIMED_OUT: ArkWeb_NetError
A connection attempt timed out.
Sourcepub const ARKWEB_ERR_HOST_RESOLVER_QUEUE_TOO_LARGE: ArkWeb_NetError
pub const ARKWEB_ERR_HOST_RESOLVER_QUEUE_TOO_LARGE: ArkWeb_NetError
There are too many pending DNS resolves, so a request in the queue was aborted.
Sourcepub const ARKWEB_ERR_SOCKS_CONNECTION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKS_CONNECTION_FAILED: ArkWeb_NetError
Failed establishing a connection to the SOCKS proxy server for a target host.
Sourcepub const ARKWEB_ERR_SOCKS_CONNECTION_HOST_UNREACHABLE: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKS_CONNECTION_HOST_UNREACHABLE: ArkWeb_NetError
The SOCKS proxy server failed establishing connection to the target host because that host is unreachable.
Sourcepub const ARKWEB_ERR_ALPN_NEGOTIATION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_ALPN_NEGOTIATION_FAILED: ArkWeb_NetError
The request to negotiate an alternate protocol failed.
Sourcepub const ARKWEB_ERR_SSL_NO_RENEGOTIATION: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_NO_RENEGOTIATION: ArkWeb_NetError
The peer sent an SSL no_renegotiation alert message.
Sourcepub const ARKWEB_ERR_WINSOCK_UNEXPECTED_WRITTEN_BYTES: ArkWeb_NetError
pub const ARKWEB_ERR_WINSOCK_UNEXPECTED_WRITTEN_BYTES: ArkWeb_NetError
Winsock sometimes reports more data written than passed. This is probably due to a broken LSP.
Sourcepub const ARKWEB_ERR_SSL_DECOMPRESSION_FAILURE_ALERT: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_DECOMPRESSION_FAILURE_ALERT: ArkWeb_NetError
An SSL peer sent us a fatal decompression_failure alert. This typically occurs when a peer selects DEFLATE compression in the mistaken belief that it supports it.
Sourcepub const ARKWEB_ERR_SSL_BAD_RECORD_MAC_ALERT: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_BAD_RECORD_MAC_ALERT: ArkWeb_NetError
An SSL peer sent us a fatal bad_record_mac alert. This has been observed from servers with buggy DEFLATE support.
Sourcepub const ARKWEB_ERR_PROXY_AUTH_REQUESTED: ArkWeb_NetError
pub const ARKWEB_ERR_PROXY_AUTH_REQUESTED: ArkWeb_NetError
The proxy requested authentication (for tunnel establishment).
Sourcepub const ARKWEB_ERR_PROXY_CONNECTION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_PROXY_CONNECTION_FAILED: ArkWeb_NetError
Could not create a connection to the proxy server. An error occurred either in resolving its name, or in connecting a socket to it. Note that this does NOT include failures during the actual “CONNECT” method of an HTTP proxy.
Sourcepub const ARKWEB_ERR_MANDATORY_PROXY_CONFIGURATION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_MANDATORY_PROXY_CONFIGURATION_FAILED: ArkWeb_NetError
A mandatory proxy configuration could not be used. Currently this means that a mandatory PAC script could not be fetched, parsed or executed.
Sourcepub const ARKWEB_ERR_PRECONNECT_MAX_SOCKET_LIMIT: ArkWeb_NetError
pub const ARKWEB_ERR_PRECONNECT_MAX_SOCKET_LIMIT: ArkWeb_NetError
We’ve hit the max socket limit for the socket pool while preconnecting. We don’t bother trying to preconnect more sockets.
Sourcepub const ARKWEB_ERR_SSL_CLIENT_AUTH_PRIVATE_KEY_ACCESS_DENIED: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_CLIENT_AUTH_PRIVATE_KEY_ACCESS_DENIED: ArkWeb_NetError
The permission to use the SSL client certificate’s private key was denied.
Sourcepub const ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_NO_PRIVATE_KEY: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_NO_PRIVATE_KEY: ArkWeb_NetError
The SSL client certificate has no private key.
Sourcepub const ARKWEB_ERR_PROXY_CERTIFICATE_INVALID: ArkWeb_NetError
pub const ARKWEB_ERR_PROXY_CERTIFICATE_INVALID: ArkWeb_NetError
The certificate presented by the HTTPS Proxy was invalid.
Sourcepub const ARKWEB_ERR_NAME_RESOLUTION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_NAME_RESOLUTION_FAILED: ArkWeb_NetError
An error occurred when trying to do a name resolution (DNS).
Sourcepub const ARKWEB_ERR_NETWORK_ACCESS_DENIED: ArkWeb_NetError
pub const ARKWEB_ERR_NETWORK_ACCESS_DENIED: ArkWeb_NetError
Permission to access the network was denied. This is used to distinguish errors that were most likely caused by a firewall from other access denied errors. See also ERR_ACCESS_DENIED.
Sourcepub const ARKWEB_ERR_TEMPORARILY_THROTTLED: ArkWeb_NetError
pub const ARKWEB_ERR_TEMPORARILY_THROTTLED: ArkWeb_NetError
The request throttler module cancelled this request to avoid DDOS.
Sourcepub const ARKWEB_ERR_HTTPS_PROXY_TUNNEL_RESPONSE_REDIRECT: ArkWeb_NetError
pub const ARKWEB_ERR_HTTPS_PROXY_TUNNEL_RESPONSE_REDIRECT: ArkWeb_NetError
A request to create an SSL tunnel connection through the HTTPS proxy received a 302 (temporary redirect, response. The response body might include a description of why the request failed.
Sourcepub const ARKWEB_ERR_SSL_CLIENT_AUTH_SIGNATURE_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_CLIENT_AUTH_SIGNATURE_FAILED: ArkWeb_NetError
We were unable to sign the CertificateVerify data of an SSL client auth handshake with the client certificate’s private key. Possible causes for this include the user implicitly or explicitly denying access to the private key, the private key may not be valid for signing, the key may be relying on a cached handle which is no longer valid, or the CSP won’t allow arbitrary data to be signed.
Sourcepub const ARKWEB_ERR_MSG_TOO_BIG: ArkWeb_NetError
pub const ARKWEB_ERR_MSG_TOO_BIG: ArkWeb_NetError
The message was too large for the transport. (for example a UDP message which exceeds size threshold).
Sourcepub const ARKWEB_ERR_WS_PROTOCOL_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_WS_PROTOCOL_ERROR: ArkWeb_NetError
Websocket protocol error. Indicates that we are terminating the connection due to a malformed frame or other protocol violation.
Sourcepub const ARKWEB_ERR_ADDRESS_IN_USE: ArkWeb_NetError
pub const ARKWEB_ERR_ADDRESS_IN_USE: ArkWeb_NetError
Returned when attempting to bind an address that is already in use.
Sourcepub const ARKWEB_ERR_SSL_HANDSHAKE_NOT_COMPLETED: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_HANDSHAKE_NOT_COMPLETED: ArkWeb_NetError
An operation failed because the SSL handshake has not completed.
Sourcepub const ARKWEB_ERR_SSL_BAD_PEER_PUBLIC_KEY: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_BAD_PEER_PUBLIC_KEY: ArkWeb_NetError
SSL peer’s public key is invalid.
Sourcepub const ARKWEB_ERR_SSL_PINNED_KEY_NOT_IN_CERT_CHAIN: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_PINNED_KEY_NOT_IN_CERT_CHAIN: ArkWeb_NetError
The certificate didn’t match the built-in public key pins for the host name. The pins are set in net/http/transport_security_state.cc and require that one of a set of public keys exist on the path from the leaf to the root.
Sourcepub const ARKWEB_ERR_CLIENT_AUTH_CERT_TYPE_UNSUPPORTED: ArkWeb_NetError
pub const ARKWEB_ERR_CLIENT_AUTH_CERT_TYPE_UNSUPPORTED: ArkWeb_NetError
Server request for client certificate did not contain any types we support.
Sourcepub const ARKWEB_ERR_SSL_DECRYPT_ERROR_ALERT: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_DECRYPT_ERROR_ALERT: ArkWeb_NetError
An SSL peer sent us a fatal decrypt_error alert. This typically occurs when a peer could not correctly verify a signature (in CertificateVerify or ServerKeyExchange, or validate a Finished message.
Sourcepub const ARKWEB_ERR_WS_THROTTLE_QUEUE_TOO_LARGE: ArkWeb_NetError
pub const ARKWEB_ERR_WS_THROTTLE_QUEUE_TOO_LARGE: ArkWeb_NetError
There are too many pending WebSocketJob instances, so the new job was not pushed to the queue.
Sourcepub const ARKWEB_ERR_SSL_SERVER_CERT_CHANGED: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_SERVER_CERT_CHANGED: ArkWeb_NetError
The SSL server certificate changed in a renegotiation.
Sourcepub const ARKWEB_ERR_SSL_UNRECOGNIZED_NAME_ALERT: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_UNRECOGNIZED_NAME_ALERT: ArkWeb_NetError
The SSL server sent us a fatal unrecognized_name alert.
Sourcepub const ARKWEB_ERR_SOCKET_SET_RECEIVE_BUFFER_SIZE_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKET_SET_RECEIVE_BUFFER_SIZE_ERROR: ArkWeb_NetError
Failed to set the socket’s receive buffer size as requested.
Sourcepub const ARKWEB_ERR_SOCKET_SET_SEND_BUFFER_SIZE_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKET_SET_SEND_BUFFER_SIZE_ERROR: ArkWeb_NetError
Failed to set the socket’s send buffer size as requested.
Sourcepub const ARKWEB_ERR_SOCKET_RECEIVE_BUFFER_SIZE_UNCHANGEABLE: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKET_RECEIVE_BUFFER_SIZE_UNCHANGEABLE: ArkWeb_NetError
Failed to set the socket’s receive buffer size as requested, despite success return code from setsockopt.
Sourcepub const ARKWEB_ERR_SOCKET_SEND_BUFFER_SIZE_UNCHANGEABLE: ArkWeb_NetError
pub const ARKWEB_ERR_SOCKET_SEND_BUFFER_SIZE_UNCHANGEABLE: ArkWeb_NetError
Failed to set the socket’s send buffer size as requested, despite success return code from setsockopt.
Sourcepub const ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_BAD_FORMAT: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_BAD_FORMAT: ArkWeb_NetError
Failed to import a client certificate from the platform store into the SSL library.
Sourcepub const ARKWEB_ERR_ICANN_NAME_COLLISION: ArkWeb_NetError
pub const ARKWEB_ERR_ICANN_NAME_COLLISION: ArkWeb_NetError
Resolving a hostname to an IP address list included the IPv4 address “127.0.53.53”. This is a special IP address which ICANN has recommended to indicate there was a name collision, and alert admins to a potential problem.
Sourcepub const ARKWEB_ERR_SSL_SERVER_CERT_BAD_FORMAT: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_SERVER_CERT_BAD_FORMAT: ArkWeb_NetError
The SSL server presented a certificate which could not be decoded. This is not a certificate error code as no X509Certificate object is available. This error is fatal.
Sourcepub const ARKWEB_ERR_CT_STH_PARSING_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_CT_STH_PARSING_FAILED: ArkWeb_NetError
Certificate Transparency: Received a signed tree head that failed to parse.
Sourcepub const ARKWEB_ERR_CT_STH_INCOMPLETE: ArkWeb_NetError
pub const ARKWEB_ERR_CT_STH_INCOMPLETE: ArkWeb_NetError
Certificate Transparency: Received a signed tree head whose JSON parsing was OK but was missing some of the fields.
Sourcepub const ARKWEB_ERR_UNABLE_TO_REUSE_CONNECTION_FOR_PROXY_AUTH: ArkWeb_NetError
pub const ARKWEB_ERR_UNABLE_TO_REUSE_CONNECTION_FOR_PROXY_AUTH: ArkWeb_NetError
The attempt to reuse a connection to send proxy auth credentials failed before the AuthController was used to generate credentials. The caller should reuse the controller with a new connection. This error is only used internally by the network stack.
Sourcepub const ARKWEB_ERR_CT_CONSISTENCY_PROOF_PARSING_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_CT_CONSISTENCY_PROOF_PARSING_FAILED: ArkWeb_NetError
Certificate Transparency: Failed to parse the received consistency proof.
Sourcepub const ARKWEB_ERR_SSL_OBSOLETE_CIPHER: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_OBSOLETE_CIPHER: ArkWeb_NetError
The SSL server required an unsupported cipher suite that has since been removed. This error will temporarily be signaled on a fallback for one or two releases immediately following a cipher suite’s removal, after which the fallback will be removed.
Sourcepub const ARKWEB_ERR_WS_UPGRADE: ArkWeb_NetError
pub const ARKWEB_ERR_WS_UPGRADE: ArkWeb_NetError
When a WebSocket handshake is done successfully and the connection has been upgraded, the URLRequest is cancelled with this error code.
Sourcepub const ARKWEB_ERR_READ_IF_READY_NOT_IMPLEMENTED: ArkWeb_NetError
pub const ARKWEB_ERR_READ_IF_READY_NOT_IMPLEMENTED: ArkWeb_NetError
Socket ReadIfReady support is not implemented. This error should not be user visible, because the normal Read(, method is used as a fallback.
Sourcepub const ARKWEB_ERR_NO_BUFFER_SPACE: ArkWeb_NetError
pub const ARKWEB_ERR_NO_BUFFER_SPACE: ArkWeb_NetError
No socket buffer space is available.
Sourcepub const ARKWEB_ERR_SSL_CLIENT_AUTH_NO_COMMON_ALGORITHMS: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_CLIENT_AUTH_NO_COMMON_ALGORITHMS: ArkWeb_NetError
There were no common signature algorithms between our client certificate private key and the server’s preferences.
Sourcepub const ARKWEB_ERR_EARLY_DATA_REJECTED: ArkWeb_NetError
pub const ARKWEB_ERR_EARLY_DATA_REJECTED: ArkWeb_NetError
TLS 1.3 early data was rejected by the server. This will be received before any data is returned from the socket. The request should be retried with early data disabled.
Sourcepub const ARKWEB_ERR_WRONG_VERSION_ON_EARLY_DATA: ArkWeb_NetError
pub const ARKWEB_ERR_WRONG_VERSION_ON_EARLY_DATA: ArkWeb_NetError
TLS 1.3 early data was offered, but the server responded with TLS 1.2 or earlier. This is an internal error code to account for a backwards-compatibility issue with early data and TLS 1.2. It will be received before any data is returned from the socket. The request should be retried with early data disabled. See https://tools.ietf.org/html/rfc8446#appendix-D.3 for details.
Sourcepub const ARKWEB_ERR_TLS13_DOWNGRADE_DETECTED: ArkWeb_NetError
pub const ARKWEB_ERR_TLS13_DOWNGRADE_DETECTED: ArkWeb_NetError
TLS 1.3 was enabled, but a lower version was negotiated and the server returned a value indicating it supported TLS 1.3. This is part of a security check in TLS 1.3, but it may also indicate the user is behind a buggy TLS-terminating proxy which implemented TLS 1.2 incorrectly. (See rhttps://crbug.com/boringssl/226.,
Sourcepub const ARKWEB_ERR_SSL_KEY_USAGE_INCOMPATIBLE: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_KEY_USAGE_INCOMPATIBLE: ArkWeb_NetError
The server’s certificate has a keyUsage extension incompatible with the negotiated TLS key exchange method.
Sourcepub const ARKWEB_ERR_INVALID_ECH_CONFIG_LIST: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_ECH_CONFIG_LIST: ArkWeb_NetError
The ECHConfigList fetched over DNS cannot be parsed.
Sourcepub const ARKWEB_ERR_ECH_NOT_NEGOTIATED: ArkWeb_NetError
pub const ARKWEB_ERR_ECH_NOT_NEGOTIATED: ArkWeb_NetError
ECH was enabled, but the server was unable to decrypt the encrypted ClientHello.
Sourcepub const ARKWEB_ERR_ECH_FALLBACK_CERTIFICATE_INVALID: ArkWeb_NetError
pub const ARKWEB_ERR_ECH_FALLBACK_CERTIFICATE_INVALID: ArkWeb_NetError
ECH was enabled, the server was unable to decrypt the encrypted ClientHello, and additionally did not present a certificate valid for the public name.
Sourcepub const ARKWEB_ERR_CERT_COMMON_NAME_INVALID: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_COMMON_NAME_INVALID: ArkWeb_NetError
The server responded with a certificate whose common name did not match the host name. This could mean:
- An attacker has redirected our traffic to their server and is presenting a certificate for which they know the private key.
- The server is misconfigured and responding with the wrong cert.
- The user is on a wireless network and is being redirected to the network’s login page.
- The OS has used a DNS search suffix and the server doesn’t have a certificate for the abbreviated name in the address bar.
Sourcepub const ARKWEB_ERR_CERT_DATE_INVALID: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_DATE_INVALID: ArkWeb_NetError
The server responded with a certificate that, by our clock, appears to either not yet be valid or to have expired. This could mean:
- An attacker is presenting an old certificate for which they have managed to obtain the private key.
- The server is misconfigured and is not presenting a valid cert.
- Our clock is wrong.
Sourcepub const ARKWEB_ERR_CERT_AUTHORITY_INVALID: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_AUTHORITY_INVALID: ArkWeb_NetError
The server responded with a certificate that is signed by an authority we don’t trust. The could mean:
- An attacker has substituted the real certificate for a cert that contains their public key and is signed by their cousin.
- The server operator has a legitimate certificate from a CA we don’t know about, but should trust.
- The server is presenting a self-signed certificate, providing no defense against active attackers (but foiling passive attackers).
Sourcepub const ARKWEB_ERR_CERT_CONTAINS_ERRORS: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_CONTAINS_ERRORS: ArkWeb_NetError
The server responded with a certificate that contains errors. This error is not recoverable. MSDN describes this error as follows: “The SSL certificate contains errors.” NOTE: It’s unclear how this differs from ERR_CERT_INVALID. For consistency, use that code instead of this one from now on.
Sourcepub const ARKWEB_ERR_CERT_NO_REVOCATION_MECHANISM: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_NO_REVOCATION_MECHANISM: ArkWeb_NetError
The certificate has no mechanism for determining if it is revoked. In effect, this certificate cannot be revoked.
Sourcepub const ARKWEB_ERR_CERT_UNABLE_TO_CHECK_REVOCATION: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_UNABLE_TO_CHECK_REVOCATION: ArkWeb_NetError
Revocation information for the security certificate for this site is not available. This could mean:
- An attacker has compromised the private key in the certificate and is blocking our attempt to find out that the cert was revoked.
- The certificate is unrevoked, but the revocation server is busy or unavailable.
Sourcepub const ARKWEB_ERR_CERT_REVOKED: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_REVOKED: ArkWeb_NetError
The server responded with a certificate has been revoked. We have the capability to ignore this error, but it is probably not the thing to do.
Sourcepub const ARKWEB_ERR_CERT_INVALID: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_INVALID: ArkWeb_NetError
The server responded with a certificate that is invalid. This error is not recoverable. MSDN describes this error as follows: “The SSL certificate is invalid.”
Sourcepub const ARKWEB_ERR_CERT_WEAK_SIGNATURE_ALGORITHM: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_WEAK_SIGNATURE_ALGORITHM: ArkWeb_NetError
The server responded with a certificate that is signed using a weak signature algorithm.
Sourcepub const ARKWEB_ERR_CERT_NON_UNIQUE_NAME: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_NON_UNIQUE_NAME: ArkWeb_NetError
The host name specified in the certificate is not unique.
Sourcepub const ARKWEB_ERR_CERT_WEAK_KEY: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_WEAK_KEY: ArkWeb_NetError
The server responded with a certificate that contains a weak key (e.g. a too-small RSA key).
Sourcepub const ARKWEB_ERR_CERT_NAME_CONSTRAINT_VIOLATION: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_NAME_CONSTRAINT_VIOLATION: ArkWeb_NetError
The certificate claimed DNS names that are in violation of name constraints.
Sourcepub const ARKWEB_ERR_CERT_VALIDITY_TOO_LONG: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_VALIDITY_TOO_LONG: ArkWeb_NetError
The certificate’s validity period is too long.
Sourcepub const ARKWEB_ERR_CERTIFICATE_TRANSPARENCY_REQUIRED: ArkWeb_NetError
pub const ARKWEB_ERR_CERTIFICATE_TRANSPARENCY_REQUIRED: ArkWeb_NetError
Certificate Transparency was required for this connection, but the server did not provide CT information that complied with the policy.
Sourcepub const ARKWEB_ERR_CERT_SYMANTEC_LEGACY: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_SYMANTEC_LEGACY: ArkWeb_NetError
The certificate chained to a legacy Symantec root that is no longer trusted.
Sourcepub const ARKWEB_ERR_CERT_KNOWN_INTERCEPTION_BLOCKED: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_KNOWN_INTERCEPTION_BLOCKED: ArkWeb_NetError
The certificate is known to be used for interception by an entity other the device owner.
Sourcepub const ARKWEB_ERR_SSL_OBSOLETE_VERSION_OR_CIPHER: ArkWeb_NetError
pub const ARKWEB_ERR_SSL_OBSOLETE_VERSION_OR_CIPHER: ArkWeb_NetError
The connection uses an obsolete version of SSL/TLS or cipher.
Sourcepub const ARKWEB_ERR_CERT_END: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_END: ArkWeb_NetError
The value immediately past the last certificate error code.
Sourcepub const ARKWEB_ERR_INVALID_URL: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_URL: ArkWeb_NetError
The URL is invalid.
Sourcepub const ARKWEB_ERR_DISALLOWED_URL_SCHEME: ArkWeb_NetError
pub const ARKWEB_ERR_DISALLOWED_URL_SCHEME: ArkWeb_NetError
The scheme of the URL is disallowed.
Sourcepub const ARKWEB_ERR_UNKNOWN_URL_SCHEME: ArkWeb_NetError
pub const ARKWEB_ERR_UNKNOWN_URL_SCHEME: ArkWeb_NetError
The scheme of the URL is unknown.
Sourcepub const ARKWEB_ERR_INVALID_REDIRECT: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_REDIRECT: ArkWeb_NetError
Attempting to load an URL resulted in a redirect to an invalid URL.
Sourcepub const ARKWEB_ERR_TOO_MANY_REDIRECTS: ArkWeb_NetError
pub const ARKWEB_ERR_TOO_MANY_REDIRECTS: ArkWeb_NetError
Attempting to load an URL resulted in too many redirects.
Sourcepub const ARKWEB_ERR_UNSAFE_REDIRECT: ArkWeb_NetError
pub const ARKWEB_ERR_UNSAFE_REDIRECT: ArkWeb_NetError
Attempting to load an URL resulted in an unsafe redirect (e.g., a redirect to file:// is considered unsafe).
Sourcepub const ARKWEB_ERR_UNSAFE_PORT: ArkWeb_NetError
pub const ARKWEB_ERR_UNSAFE_PORT: ArkWeb_NetError
Attempting to load an URL with an unsafe port number.
Sourcepub const ARKWEB_ERR_INVALID_RESPONSE: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_RESPONSE: ArkWeb_NetError
The server’s response was invalid.
Sourcepub const ARKWEB_ERR_INVALID_CHUNKED_ENCODING: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_CHUNKED_ENCODING: ArkWeb_NetError
Error in chunked transfer encoding.
Sourcepub const ARKWEB_ERR_METHOD_UNSUPPORTED: ArkWeb_NetError
pub const ARKWEB_ERR_METHOD_UNSUPPORTED: ArkWeb_NetError
The server did not support the request method.
Sourcepub const ARKWEB_ERR_UNEXPECTED_PROXY_AUTH: ArkWeb_NetError
pub const ARKWEB_ERR_UNEXPECTED_PROXY_AUTH: ArkWeb_NetError
The response was 407 (Proxy Authentication Required,, yet we did not send the request to a proxy.
Sourcepub const ARKWEB_ERR_EMPTY_RESPONSE: ArkWeb_NetError
pub const ARKWEB_ERR_EMPTY_RESPONSE: ArkWeb_NetError
The server closed the connection without sending any data.
Sourcepub const ARKWEB_ERR_RESPONSE_HEADERS_TOO_BIG: ArkWeb_NetError
pub const ARKWEB_ERR_RESPONSE_HEADERS_TOO_BIG: ArkWeb_NetError
The headers section of the response is too large.
Sourcepub const ARKWEB_ERR_PAC_SCRIPT_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_PAC_SCRIPT_FAILED: ArkWeb_NetError
The evaluation of the PAC script failed.
Sourcepub const ARKWEB_ERR_REQUEST_RANGE_NOT_SATISFIABLE: ArkWeb_NetError
pub const ARKWEB_ERR_REQUEST_RANGE_NOT_SATISFIABLE: ArkWeb_NetError
The response was 416 (Requested range not satisfiable, and the server cannot satisfy the range requested.
Sourcepub const ARKWEB_ERR_MALFORMED_IDENTITY: ArkWeb_NetError
pub const ARKWEB_ERR_MALFORMED_IDENTITY: ArkWeb_NetError
The identity used for authentication is invalid.
Sourcepub const ARKWEB_ERR_CONTENT_DECODING_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_CONTENT_DECODING_FAILED: ArkWeb_NetError
Content decoding of the response body failed.
Sourcepub const ARKWEB_ERR_NETWORK_IO_SUSPENDED: ArkWeb_NetError
pub const ARKWEB_ERR_NETWORK_IO_SUSPENDED: ArkWeb_NetError
An operation could not be completed because all network IO is suspended.
Sourcepub const ARKWEB_ERR_SYN_REPLY_NOT_RECEIVED: ArkWeb_NetError
pub const ARKWEB_ERR_SYN_REPLY_NOT_RECEIVED: ArkWeb_NetError
FLIP data received without receiving a SYN_REPLY on the stream.
Sourcepub const ARKWEB_ERR_ENCODING_CONVERSION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_ENCODING_CONVERSION_FAILED: ArkWeb_NetError
Converting the response to target encoding failed.
Sourcepub const ARKWEB_ERR_UNRECOGNIZED_FTP_DIRECTORY_LISTING_FORMAT: ArkWeb_NetError
pub const ARKWEB_ERR_UNRECOGNIZED_FTP_DIRECTORY_LISTING_FORMAT: ArkWeb_NetError
The server sent an FTP directory listing in a format we do not understand.
Sourcepub const ARKWEB_ERR_NO_SUPPORTED_PROXIES: ArkWeb_NetError
pub const ARKWEB_ERR_NO_SUPPORTED_PROXIES: ArkWeb_NetError
There are no supported proxies in the provided list.
Sourcepub const ARKWEB_ERR_HTTP2_PROTOCOL_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_PROTOCOL_ERROR: ArkWeb_NetError
There is an HTTP/2 protocol error.
Sourcepub const ARKWEB_ERR_INVALID_AUTH_CREDENTIALS: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_AUTH_CREDENTIALS: ArkWeb_NetError
Credentials could not be established during HTTP Authentication.
Sourcepub const ARKWEB_ERR_UNSUPPORTED_AUTH_SCHEME: ArkWeb_NetError
pub const ARKWEB_ERR_UNSUPPORTED_AUTH_SCHEME: ArkWeb_NetError
An HTTP Authentication scheme was tried which is not supported on this machine.
Sourcepub const ARKWEB_ERR_ENCODING_DETECTION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_ENCODING_DETECTION_FAILED: ArkWeb_NetError
Detecting the encoding of the response failed.
Sourcepub const ARKWEB_ERR_MISSING_AUTH_CREDENTIALS: ArkWeb_NetError
pub const ARKWEB_ERR_MISSING_AUTH_CREDENTIALS: ArkWeb_NetError
(GSSAPI, No Kerberos credentials were available during HTTP Authentication.
Sourcepub const ARKWEB_ERR_UNEXPECTED_SECURITY_LIBRARY_STATUS: ArkWeb_NetError
pub const ARKWEB_ERR_UNEXPECTED_SECURITY_LIBRARY_STATUS: ArkWeb_NetError
An unexpected, but documented, SSPI or GSSAPI status code was returned.
Sourcepub const ARKWEB_ERR_MISCONFIGURED_AUTH_ENVIRONMENT: ArkWeb_NetError
pub const ARKWEB_ERR_MISCONFIGURED_AUTH_ENVIRONMENT: ArkWeb_NetError
The environment was not set up correctly for authentication (for example, no KDC could be found or the principal is unknown.
Sourcepub const ARKWEB_ERR_UNDOCUMENTED_SECURITY_LIBRARY_STATUS: ArkWeb_NetError
pub const ARKWEB_ERR_UNDOCUMENTED_SECURITY_LIBRARY_STATUS: ArkWeb_NetError
An undocumented SSPI or GSSAPI status code was returned.
Sourcepub const ARKWEB_ERR_RESPONSE_BODY_TOO_BIG_TO_DRAIN: ArkWeb_NetError
pub const ARKWEB_ERR_RESPONSE_BODY_TOO_BIG_TO_DRAIN: ArkWeb_NetError
The HTTP response was too big to drain.
Sourcepub const ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_CONTENT_LENGTH: ArkWeb_NetError
pub const ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_CONTENT_LENGTH: ArkWeb_NetError
The HTTP response contained multiple distinct Content-Length headers.
Sourcepub const ARKWEB_ERR_INCOMPLETE_HTTP2_HEADERS: ArkWeb_NetError
pub const ARKWEB_ERR_INCOMPLETE_HTTP2_HEADERS: ArkWeb_NetError
HTTP/2 headers have been received, but not all of them - status or version headers are missing, so we’re expecting additional frames to complete them.
Sourcepub const ARKWEB_ERR_PAC_NOT_IN_DHCP: ArkWeb_NetError
pub const ARKWEB_ERR_PAC_NOT_IN_DHCP: ArkWeb_NetError
No PAC URL configuration could be retrieved from DHCP. This can indicate either a failure to retrieve the DHCP configuration, or that there was no PAC URL configured in DHCP.
Sourcepub const ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_CONTENT_DISPOSITION: ArkWeb_NetError
pub const ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_CONTENT_DISPOSITION: ArkWeb_NetError
The HTTP response contained multiple Content-Disposition headers.
Sourcepub const ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_LOCATION: ArkWeb_NetError
pub const ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_LOCATION: ArkWeb_NetError
The HTTP response contained multiple Location headers.
Sourcepub const ARKWEB_ERR_HTTP2_SERVER_REFUSED_STREAM: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_SERVER_REFUSED_STREAM: ArkWeb_NetError
HTTP/2 server refused the request without processing, and sent either a GOAWAY frame with error code NO_ERROR and Last-Stream-ID lower than the stream id corresponding to the request indicating that this request has not been processed yet, or a RST_STREAM frame with error code REFUSED_STREAM. Client MAY retry (on a different connection). See RFC7540 Section 8.1.4.
Sourcepub const ARKWEB_ERR_HTTP2_PING_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_PING_FAILED: ArkWeb_NetError
HTTP/2 server didn’t respond to the PING message.
Sourcepub const ARKWEB_ERR_CONTENT_LENGTH_MISMATCH: ArkWeb_NetError
pub const ARKWEB_ERR_CONTENT_LENGTH_MISMATCH: ArkWeb_NetError
The HTTP response body transferred fewer bytes than were advertised by the Content-Length header when the connection is closed.
Sourcepub const ARKWEB_ERR_INCOMPLETE_CHUNKED_ENCODING: ArkWeb_NetError
pub const ARKWEB_ERR_INCOMPLETE_CHUNKED_ENCODING: ArkWeb_NetError
The HTTP response body is transferred with Chunked-Encoding, but the terminating zero-length chunk was never sent when the connection is closed.
Sourcepub const ARKWEB_ERR_QUIC_PROTOCOL_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_QUIC_PROTOCOL_ERROR: ArkWeb_NetError
There is a QUIC protocol error.
Sourcepub const ARKWEB_ERR_RESPONSE_HEADERS_TRUNCATED: ArkWeb_NetError
pub const ARKWEB_ERR_RESPONSE_HEADERS_TRUNCATED: ArkWeb_NetError
The HTTP headers were truncated by an EOF.
Sourcepub const ARKWEB_ERR_QUIC_HANDSHAKE_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_QUIC_HANDSHAKE_FAILED: ArkWeb_NetError
The QUIC crypto handshake failed. This means that the server was unable to read any requests sent, so they may be resent.
Sourcepub const ARKWEB_ERR_HTTP2_INADEQUATE_TRANSPORT_SECURITY: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_INADEQUATE_TRANSPORT_SECURITY: ArkWeb_NetError
Transport security is inadequate for the HTTP/2 version.
Sourcepub const ARKWEB_ERR_HTTP2_FLOW_CONTROL_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_FLOW_CONTROL_ERROR: ArkWeb_NetError
The peer violated HTTP/2 flow control.
Sourcepub const ARKWEB_ERR_HTTP2_FRAME_SIZE_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_FRAME_SIZE_ERROR: ArkWeb_NetError
The peer sent an improperly sized HTTP/2 frame.
Sourcepub const ARKWEB_ERR_HTTP2_COMPRESSION_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_COMPRESSION_ERROR: ArkWeb_NetError
Decoding or encoding of compressed HTTP/2 headers failed.
Sourcepub const ARKWEB_ERR_PROXY_AUTH_REQUESTED_WITH_NO_CONNECTION: ArkWeb_NetError
pub const ARKWEB_ERR_PROXY_AUTH_REQUESTED_WITH_NO_CONNECTION: ArkWeb_NetError
Proxy Auth Requested without a valid Client Socket Handle.
Sourcepub const ARKWEB_ERR_HTTP_1_1_REQUIRED: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP_1_1_REQUIRED: ArkWeb_NetError
HTTP_1_1_REQUIRED error code received on HTTP/2 session.
Sourcepub const ARKWEB_ERR_PROXY_HTTP_1_1_REQUIRED: ArkWeb_NetError
pub const ARKWEB_ERR_PROXY_HTTP_1_1_REQUIRED: ArkWeb_NetError
HTTP_1_1_REQUIRED error code received on HTTP/2 session to proxy.
Sourcepub const ARKWEB_ERR_PAC_SCRIPT_TERMINATED: ArkWeb_NetError
pub const ARKWEB_ERR_PAC_SCRIPT_TERMINATED: ArkWeb_NetError
The PAC script terminated fatally and must be reloaded.
Sourcepub const ARKWEB_ERR_INVALID_HTTP_RESPONSE: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_HTTP_RESPONSE: ArkWeb_NetError
The server was expected to return an HTTP/1.x response, but did not. Rather than treat it as HTTP/0.9, this error is returned.
Sourcepub const ARKWEB_ERR_CONTENT_DECODING_INIT_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_CONTENT_DECODING_INIT_FAILED: ArkWeb_NetError
Initializing content decoding failed.
Sourcepub const ARKWEB_ERR_HTTP2_RST_STREAM_NO_ERROR_RECEIVED: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_RST_STREAM_NO_ERROR_RECEIVED: ArkWeb_NetError
Received HTTP/2 RST_STREAM frame with NO_ERROR error code. This error should be handled internally by HTTP/2 code, and should not make it above the SpdyStream layer.
Sourcepub const ARKWEB_ERR_HTTP2_PUSHED_STREAM_NOT_AVAILABLE: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_PUSHED_STREAM_NOT_AVAILABLE: ArkWeb_NetError
The pushed stream claimed by the request is no longer available.
Sourcepub const ARKWEB_ERR_HTTP2_CLAIMED_PUSHED_STREAM_RESET_BY_SERVER: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_CLAIMED_PUSHED_STREAM_RESET_BY_SERVER: ArkWeb_NetError
A pushed stream was claimed and later reset by the server. When this happens, the request should be retried.
Sourcepub const ARKWEB_ERR_TOO_MANY_RETRIES: ArkWeb_NetError
pub const ARKWEB_ERR_TOO_MANY_RETRIES: ArkWeb_NetError
An HTTP transaction was retried too many times due for authentication or invalid certificates.
Sourcepub const ARKWEB_ERR_HTTP2_STREAM_CLOSED: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_STREAM_CLOSED: ArkWeb_NetError
Received an HTTP/2 frame on a closed stream.
Sourcepub const ARKWEB_ERR_HTTP2_CLIENT_REFUSED_STREAM: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_CLIENT_REFUSED_STREAM: ArkWeb_NetError
Client is refusing an HTTP/2 stream.
Sourcepub const ARKWEB_ERR_HTTP2_PUSHED_RESPONSE_DOES_NOT_MATCH: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP2_PUSHED_RESPONSE_DOES_NOT_MATCH: ArkWeb_NetError
A pushed HTTP/2 stream was claimed by a request based on matching URL and request headers, but the pushed response headers do not match the request.
Sourcepub const ARKWEB_ERR_HTTP_RESPONSE_CODE_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_HTTP_RESPONSE_CODE_FAILURE: ArkWeb_NetError
The server returned a non-2xx HTTP response code.
Sourcepub const ARKWEB_ERR_QUIC_UNKNOWN_CERT_ROOT: ArkWeb_NetError
pub const ARKWEB_ERR_QUIC_UNKNOWN_CERT_ROOT: ArkWeb_NetError
The certificate presented on a QUIC connection does not chain to a known root and the origin connected to is not on a list of domains where unknown roots are allowed.
Sourcepub const ARKWEB_ERR_QUIC_GOAWAY_REQUEST_CAN_BE_RETRIED: ArkWeb_NetError
pub const ARKWEB_ERR_QUIC_GOAWAY_REQUEST_CAN_BE_RETRIED: ArkWeb_NetError
A GOAWAY frame has been received indicating that the request has not been processed and is therefore safe to retry on a different connection.
Sourcepub const ARKWEB_ERR_TOO_MANY_ACCEPT_CH_RESTARTS: ArkWeb_NetError
pub const ARKWEB_ERR_TOO_MANY_ACCEPT_CH_RESTARTS: ArkWeb_NetError
The ACCEPT_CH restart has been triggered too many times.
Sourcepub const ARKWEB_ERR_INCONSISTENT_IP_ADDRESS_SPACE: ArkWeb_NetError
pub const ARKWEB_ERR_INCONSISTENT_IP_ADDRESS_SPACE: ArkWeb_NetError
The IP address space of the remote endpoint differed from the previous observed value during the same request. Any cache entry for the affected request should be invalidated.
Sourcepub const ARKWEB_ERR_CACHED_IP_ADDRESS_SPACE_BLOCKED_BY_LOCAL_NETWORK_ACCESS_POLICY: ArkWeb_NetError
pub const ARKWEB_ERR_CACHED_IP_ADDRESS_SPACE_BLOCKED_BY_LOCAL_NETWORK_ACCESS_POLICY: ArkWeb_NetError
The IP address space of the cached remote endpoint is blocked by local network access check.
Sourcepub const ARKWEB_ERR_CACHE_MISS: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_MISS: ArkWeb_NetError
The cache does not have the requested entry.
Sourcepub const ARKWEB_ERR_CACHE_READ_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_READ_FAILURE: ArkWeb_NetError
Unable to read from the disk cache.
Sourcepub const ARKWEB_ERR_CACHE_WRITE_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_WRITE_FAILURE: ArkWeb_NetError
Unable to write to the disk cache.
Sourcepub const ARKWEB_ERR_CACHE_OPERATION_UNSUPPORTED: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_OPERATION_UNSUPPORTED: ArkWeb_NetError
The operation is not supported for this entry.
Sourcepub const ARKWEB_ERR_CACHE_OPEN_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_OPEN_FAILURE: ArkWeb_NetError
The disk cache is unable to open this entry.
Sourcepub const ARKWEB_ERR_CACHE_CREATE_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_CREATE_FAILURE: ArkWeb_NetError
The disk cache is unable to create this entry.
Sourcepub const ARKWEB_ERR_CACHE_RACE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_RACE: ArkWeb_NetError
Multiple transactions are racing to create disk cache entries.
Sourcepub const ARKWEB_ERR_CACHE_CHECKSUM_READ_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_CHECKSUM_READ_FAILURE: ArkWeb_NetError
The cache was unable to read a checksum record on an entry.
Sourcepub const ARKWEB_ERR_CACHE_CHECKSUM_MISMATCH: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_CHECKSUM_MISMATCH: ArkWeb_NetError
The cache found an entry with an invalid checksum.
Sourcepub const ARKWEB_ERR_CACHE_LOCK_TIMEOUT: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_LOCK_TIMEOUT: ArkWeb_NetError
Internal error code for the HTTP cache.
Sourcepub const ARKWEB_ERR_CACHE_AUTH_FAILURE_AFTER_READ: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_AUTH_FAILURE_AFTER_READ: ArkWeb_NetError
Received a challenge after the transaction has read some data, and the credentials aren’t available.
Sourcepub const ARKWEB_ERR_CACHE_ENTRY_NOT_SUITABLE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_ENTRY_NOT_SUITABLE: ArkWeb_NetError
Internal not-quite error code for the HTTP cache.
Sourcepub const ARKWEB_ERR_CACHE_DOOM_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_DOOM_FAILURE: ArkWeb_NetError
The disk cache is unable to doom this entry.
Sourcepub const ARKWEB_ERR_CACHE_OPEN_OR_CREATE_FAILURE: ArkWeb_NetError
pub const ARKWEB_ERR_CACHE_OPEN_OR_CREATE_FAILURE: ArkWeb_NetError
The disk cache is unable to open or create this entry.
Sourcepub const ARKWEB_ERR_INSECURE_RESPONSE: ArkWeb_NetError
pub const ARKWEB_ERR_INSECURE_RESPONSE: ArkWeb_NetError
The server’s response was insecure (e.g. there was a cert error).
Sourcepub const ARKWEB_ERR_NO_PRIVATE_KEY_FOR_CERT: ArkWeb_NetError
pub const ARKWEB_ERR_NO_PRIVATE_KEY_FOR_CERT: ArkWeb_NetError
An attempt to import a client certificate failed, as the user’s key database lacked a corresponding private key.
Sourcepub const ARKWEB_ERR_ADD_USER_CERT_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_ADD_USER_CERT_FAILED: ArkWeb_NetError
An error adding a certificate to the OS certificate database.
Sourcepub const ARKWEB_ERR_INVALID_SIGNED_EXCHANGE: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_SIGNED_EXCHANGE: ArkWeb_NetError
An error occurred while handling a signed exchange.
Sourcepub const ARKWEB_ERR_INVALID_WEB_BUNDLE: ArkWeb_NetError
pub const ARKWEB_ERR_INVALID_WEB_BUNDLE: ArkWeb_NetError
An error occurred while handling a Web Bundle source.
Sourcepub const ARKWEB_ERR_TRUST_TOKEN_OPERATION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_TRUST_TOKEN_OPERATION_FAILED: ArkWeb_NetError
A Trust Tokens protocol operation-executing request failed for one of a number of reasons (precondition failure, internal error, bad response).
Sourcepub const ARKWEB_ERR_TRUST_TOKEN_OPERATION_SUCCESS_WITHOUT_SENDING_REQUEST: ArkWeb_NetError
pub const ARKWEB_ERR_TRUST_TOKEN_OPERATION_SUCCESS_WITHOUT_SENDING_REQUEST: ArkWeb_NetError
When handling a Trust Tokens protocol operation-executing request, the system was able to execute the request’s Trust Tokens operation without sending the request to its destination.
Sourcepub const ARKWEB_ERR_FTP_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_FTP_FAILED: ArkWeb_NetError
A generic error for failed FTP control connection command. If possible, please use or add a more specific error code.
Sourcepub const ARKWEB_ERR_FTP_SERVICE_UNAVAILABLE: ArkWeb_NetError
pub const ARKWEB_ERR_FTP_SERVICE_UNAVAILABLE: ArkWeb_NetError
The server cannot fulfill the request at this point. This is a temporary error. FTP response code 421.
Sourcepub const ARKWEB_ERR_FTP_TRANSFER_ABORTED: ArkWeb_NetError
pub const ARKWEB_ERR_FTP_TRANSFER_ABORTED: ArkWeb_NetError
The server has aborted the transfer. FTP response code 426.
Sourcepub const ARKWEB_ERR_FTP_FILE_BUSY: ArkWeb_NetError
pub const ARKWEB_ERR_FTP_FILE_BUSY: ArkWeb_NetError
The file is busy, or some other temporary error condition on opening the file. FTP response code 450.
Sourcepub const ARKWEB_ERR_FTP_SYNTAX_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_FTP_SYNTAX_ERROR: ArkWeb_NetError
Server rejected our command because of syntax errors. FTP response codes 500, 501.
Sourcepub const ARKWEB_ERR_FTP_COMMAND_UNSUPPORTED: ArkWeb_NetError
pub const ARKWEB_ERR_FTP_COMMAND_UNSUPPORTED: ArkWeb_NetError
Server does not support the command we issued. FTP response codes 502, 504.
Sourcepub const ARKWEB_ERR_FTP_BAD_COMMAND_SEQUENCE: ArkWeb_NetError
pub const ARKWEB_ERR_FTP_BAD_COMMAND_SEQUENCE: ArkWeb_NetError
Server rejected our command because we didn’t issue the commands in right order. FTP response code 503.
Sourcepub const ARKWEB_ERR_PKCS12_IMPORT_BAD_PASSWORD: ArkWeb_NetError
pub const ARKWEB_ERR_PKCS12_IMPORT_BAD_PASSWORD: ArkWeb_NetError
PKCS #12 import failed due to incorrect password.
Sourcepub const ARKWEB_ERR_PKCS12_IMPORT_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_PKCS12_IMPORT_FAILED: ArkWeb_NetError
PKCS #12 import failed due to other error.
Sourcepub const ARKWEB_ERR_IMPORT_CA_CERT_NOT_CA: ArkWeb_NetError
pub const ARKWEB_ERR_IMPORT_CA_CERT_NOT_CA: ArkWeb_NetError
CA import failed - not a CA cert.
Sourcepub const ARKWEB_ERR_IMPORT_CERT_ALREADY_EXISTS: ArkWeb_NetError
pub const ARKWEB_ERR_IMPORT_CERT_ALREADY_EXISTS: ArkWeb_NetError
Import failed - certificate already exists in database.
Sourcepub const ARKWEB_ERR_IMPORT_CA_CERT_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_IMPORT_CA_CERT_FAILED: ArkWeb_NetError
CA import failed due to some other error.
Sourcepub const ARKWEB_ERR_IMPORT_SERVER_CERT_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_IMPORT_SERVER_CERT_FAILED: ArkWeb_NetError
Server certificate import failed due to some internal error.
Sourcepub const ARKWEB_ERR_PKCS12_IMPORT_INVALID_MAC: ArkWeb_NetError
pub const ARKWEB_ERR_PKCS12_IMPORT_INVALID_MAC: ArkWeb_NetError
PKCS #12 import failed due to invalid MAC.
Sourcepub const ARKWEB_ERR_PKCS12_IMPORT_INVALID_FILE: ArkWeb_NetError
pub const ARKWEB_ERR_PKCS12_IMPORT_INVALID_FILE: ArkWeb_NetError
PKCS #12 import failed due to invalid/corrupt file.
Sourcepub const ARKWEB_ERR_PKCS12_IMPORT_UNSUPPORTED: ArkWeb_NetError
pub const ARKWEB_ERR_PKCS12_IMPORT_UNSUPPORTED: ArkWeb_NetError
PKCS #12 import failed due to unsupported features.
Sourcepub const ARKWEB_ERR_KEY_GENERATION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_KEY_GENERATION_FAILED: ArkWeb_NetError
Key generation failed.
Sourcepub const ARKWEB_ERR_PRIVATE_KEY_EXPORT_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_PRIVATE_KEY_EXPORT_FAILED: ArkWeb_NetError
Failure to export private key.
Sourcepub const ARKWEB_ERR_SELF_SIGNED_CERT_GENERATION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_SELF_SIGNED_CERT_GENERATION_FAILED: ArkWeb_NetError
Self-signed certificate generation failed.
Sourcepub const ARKWEB_ERR_CERT_DATABASE_CHANGED: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_DATABASE_CHANGED: ArkWeb_NetError
The certificate database changed in some way.
Sourcepub const ARKWEB_ERR_CERT_VERIFIER_CHANGED: ArkWeb_NetError
pub const ARKWEB_ERR_CERT_VERIFIER_CHANGED: ArkWeb_NetError
The certificate verifier configuration changed in some way.
Sourcepub const ARKWEB_ERR_DNS_MALFORMED_RESPONSE: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_MALFORMED_RESPONSE: ArkWeb_NetError
DNS resolver received a malformed response.
Sourcepub const ARKWEB_ERR_DNS_SERVER_REQUIRES_TCP: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_SERVER_REQUIRES_TCP: ArkWeb_NetError
DNS server requires TCP.
Sourcepub const ARKWEB_ERR_DNS_SERVER_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_SERVER_FAILED: ArkWeb_NetError
DNS server failed. This error is returned for all of the following error conditions: 1 - Format error - The name server was unable to interpret the query. 2 - Server failure - The name server was unable to process this query due to a problem with the name server. 4 - Not Implemented - The name server does not support the requested kind of query. 5 - Refused - The name server refuses to perform the specified operation for policy reasons.
Sourcepub const ARKWEB_ERR_DNS_TIMED_OUT: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_TIMED_OUT: ArkWeb_NetError
DNS transaction timed out.
Sourcepub const ARKWEB_ERR_DNS_CACHE_MISS: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_CACHE_MISS: ArkWeb_NetError
The entry was not found in cache or other local sources, for lookups where only local sources were queried.
Sourcepub const ARKWEB_ERR_DNS_SEARCH_EMPTY: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_SEARCH_EMPTY: ArkWeb_NetError
Suffix search list rules prevent resolution of the given host name.
Sourcepub const ARKWEB_ERR_DNS_SORT_ERROR: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_SORT_ERROR: ArkWeb_NetError
Failed to sort addresses according to RFC3484.
Sourcepub const ARKWEB_ERR_DNS_SECURE_RESOLVER_HOSTNAME_RESOLUTION_FAILED: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_SECURE_RESOLVER_HOSTNAME_RESOLUTION_FAILED: ArkWeb_NetError
Failed to resolve the hostname of a DNS-over-HTTPS server.
Sourcepub const ARKWEB_ERR_DNS_NAME_HTTPS_ONLY: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_NAME_HTTPS_ONLY: ArkWeb_NetError
DNS identified the request as disallowed for insecure connection (http/ws). Error should be handled as if an HTTP redirect was received to redirect to https or wss.
Sourcepub const ARKWEB_ERR_DNS_REQUEST_CANCELED: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_REQUEST_CANCELED: ArkWeb_NetError
All DNS requests associated with this job have been cancelled.
Sourcepub const ARKWEB_ERR_DNS_NO_MATCHING_SUPPORTED_ALPN: ArkWeb_NetError
pub const ARKWEB_ERR_DNS_NO_MATCHING_SUPPORTED_ALPN: ArkWeb_NetError
The hostname resolution of HTTPS record was expected to be resolved with alpn values of supported protocols, but did not.