Module arkweb_scheme_handler

Module arkweb_scheme_handler 

Available on crate features api-11 and api-12 only.

Structs

ArkWeb_CustomSchemeOption
Configuration information for custom schemes.
ArkWeb_HttpBodyStream_
ArkWeb_RequestHeaderList_
ArkWeb_ResourceHandler_
ArkWeb_ResourceRequest_
ArkWeb_ResourceType
Resource type for a request.
ArkWeb_Response_
ArkWeb_SchemeHandler_

Functions

OH_ArkWebHttpBodyStream_AsyncReadapi-20
Read the http body to the buffer.
OH_ArkWebHttpBodyStream_GetPosition
Get the current position of the data stream.
OH_ArkWebHttpBodyStream_GetSize
Get the total size of the data stream.
OH_ArkWebHttpBodyStream_GetUserData
Get the user data from ArkWeb_HttpBodyStream.
OH_ArkWebHttpBodyStream_Init
Init the http body stream.
OH_ArkWebHttpBodyStream_IsChunked
Get if the data stream is chunked.
OH_ArkWebHttpBodyStream_IsEof
Returns true if all data has been consumed from this upload data stream.
OH_ArkWebHttpBodyStream_IsInMemory
Returns true if the upload data in the stream is entirely in memory, and all read requests will succeed synchronously.
OH_ArkWebHttpBodyStream_Read
Read the http body to the buffer.
OH_ArkWebHttpBodyStream_SetAsyncReadCallbackapi-20
Set the callback for OH_ArkWebHttpBodyStream_AsyncRead.
OH_ArkWebHttpBodyStream_SetReadCallback
Set the callback for OH_ArkWebHttpBodyStream_Read.
OH_ArkWebHttpBodyStream_SetUserData
Set a user data to ArkWeb_HttpBodyStream.
OH_ArkWebRequestHeaderList_Destroy
Destroy the ArkWeb_RequestHeaderList.
OH_ArkWebRequestHeaderList_GetHeader
Get the specified request header.
OH_ArkWebRequestHeaderList_GetSize
Get the request headers size.
OH_ArkWebResourceHandler_Destroy
Destroy the ArkWeb_ResourceHandler.
OH_ArkWebResourceHandler_DidFailWithError
Notify the ArkWeb that this request should be failed.
OH_ArkWebResourceHandler_DidFailWithErrorV2api-20
Notify the ArkWeb that this request should be failed.
OH_ArkWebResourceHandler_DidFinish
Notify the ArkWeb that this request should be finished and there is no more data available.
OH_ArkWebResourceHandler_DidReceiveData
Pass response body data to intercepted requests.
OH_ArkWebResourceHandler_DidReceiveResponse
Pass response headers to intercepted requests.
OH_ArkWebResourceRequest_Destroy
Destroy the ArkWeb_ResourceRequest.
OH_ArkWebResourceRequest_DestroyHttpBodyStream
Destroy the http body stream.
OH_ArkWebResourceRequest_GetFrameUrl
Get the url of frame which trigger this request.
OH_ArkWebResourceRequest_GetHttpBodyStream
Create a ArkWeb_HttpBodyStream which used to read the http body.
OH_ArkWebResourceRequest_GetMethod
Get the method of request.
OH_ArkWebResourceRequest_GetReferrer
Get the referrer of request.
OH_ArkWebResourceRequest_GetRequestHeaders
Get the OH_ArkWeb_RequestHeaderList of the request.
OH_ArkWebResourceRequest_GetResourceType
Get the resource type of request.
OH_ArkWebResourceRequest_GetUrl
Get the url of request.
OH_ArkWebResourceRequest_GetUserData
Get the user data from ArkWeb_ResourceRequest.
OH_ArkWebResourceRequest_HasGesture
Get if this is a request is triggered by user gesutre.
OH_ArkWebResourceRequest_IsMainFrame
Get if this is a request from main frame.
OH_ArkWebResourceRequest_IsRedirect
Get if this is a redirect request.
OH_ArkWebResourceRequest_SetUserData
Set a user data to ArkWeb_ResourceRequest.
OH_ArkWebResponse_GetCharset
Get the response’s charset.
OH_ArkWebResponse_GetError
Get the response’s error code.
OH_ArkWebResponse_GetHeaderByName
Get the header from the response.
OH_ArkWebResponse_GetMimeType
Get the response’s mime type.
OH_ArkWebResponse_GetStatus
Get the response’s status code.
OH_ArkWebResponse_GetStatusText
Get the response’s status text.
OH_ArkWebResponse_GetUrl
Get the resolved URL after redirects or changed as a result of HSTS.
OH_ArkWebResponse_SetCharset
Set charset to ArkWeb_Response.
OH_ArkWebResponse_SetError
Set a error code to ArkWeb_Response.
OH_ArkWebResponse_SetHeaderByName
Set a header to ArkWeb_Response.
OH_ArkWebResponse_SetMimeType
Set mime type to ArkWebResponse.
OH_ArkWebResponse_SetStatus
Set a status code to ArkWebResponse.
OH_ArkWebResponse_SetStatusText
Set a status text to ArkWebResponse.
OH_ArkWebResponse_SetUrl
Set the resolved URL after redirects or changed as a result of HSTS.
OH_ArkWebSchemeHandler_GetUserData
Get the user data from ArkWeb_SchemeHandler.
OH_ArkWebSchemeHandler_SetOnRequestStart
Set the OnRequestStart callback for SchemeHandler.
OH_ArkWebSchemeHandler_SetOnRequestStop
Set the OnRequestStop callback for SchemeHandler.
OH_ArkWebSchemeHandler_SetUserData
Set a user data to ArkWeb_SchemeHandler.
OH_ArkWebServiceWorker_ClearSchemeHandlers
Clear the handler registered on the specified web for service worker.
OH_ArkWebServiceWorker_SetSchemeHandler
Set a ArkWeb_SchemeHandler for a specific scheme to intercept requests of that scheme type.
OH_ArkWeb_ClearSchemeHandlers
Clear the handler registered on the specified web.
OH_ArkWeb_CreateResponse
Create a Response for a request.
OH_ArkWeb_CreateSchemeHandler
Create a SchemeHandler.
OH_ArkWeb_DestroyResponse
Destroy the Reponse.
OH_ArkWeb_DestroySchemeHandler
Destroy a SchemeHandler.
OH_ArkWeb_RegisterCustomSchemes
Register custom scheme to the ArkWeb.
OH_ArkWeb_ReleaseByteArray
Release the byte array acquired by native function.
OH_ArkWeb_ReleaseString
Release the string acquired by native function.
OH_ArkWeb_SetSchemeHandler
Set a ArkWeb_SchemeHandler for a specific scheme to intercept requests of that scheme type.

Type Aliases

ArkWeb_HttpBodyStream
The http body of the request.
ArkWeb_HttpBodyStreamAsyncReadCallbackapi-20
Callback when the read operation done.
ArkWeb_HttpBodyStreamInitCallback
Callback when the init operation done.
ArkWeb_HttpBodyStreamReadCallback
Callback when the read operation done.
ArkWeb_OnRequestStart
Callback for handling the request.
ArkWeb_OnRequestStop
Callback when the request is completed.
ArkWeb_RequestHeaderList
The request headers of the request.
ArkWeb_ResourceHandler
Used to intercept url requests.
ArkWeb_ResourceRequest
The info of the request.
ArkWeb_Response
The response of the intercepted request.
ArkWeb_SchemeHandler
This class is used to intercept requests for a specified scheme.