pub unsafe extern "C" fn OH_ArkWebHttpBodyStream_AsyncRead(
httpBodyStream: *const ArkWeb_HttpBodyStream,
buffer: *mut u8,
bufLen: c_int,
)Available on crate features
api-11 and api-12 and api-20 only.Expand description
Read the http body to the buffer.
The buffer must be larger than the bufLen. We will read data from a worker thread to the buffer,
so should not use the buffer in other threads before the callback to avoid concurrency issues.
Arguments
-
httpBodyStream- The ArkWeb_HttpBodyStream. -
buffer- The buffer to receive data. -
bufLen- The size of bytes to read.
Available since API-level: 20