pub unsafe extern "C" fn OH_ArkWebResourceRequest_GetMethod(
resourceRequest: *const ArkWeb_ResourceRequest,
method: *mut *mut c_char,
)Available on crate features
api-11 and api-12 only.Expand description
Get the method of request.
Arguments
-
resourceRequest- The ArkWeb_ResourceRequest. -
method- The request’s http method. This function will allocate memory for the method string and caller must release the string by OH_ArkWeb_ReleaseString.
Required System Capabilities: SystemCapability.Web.Webview.Core
Available since API-level: 12