pub unsafe extern "C" fn OH_ArkWebResponse_GetCharset(
response: *const ArkWeb_Response,
charset: *mut *mut c_char,
)Available on crate features
api-11 and api-12 only.Expand description
Get the response’s charset.
Arguments
-
response- The ArkWeb_Response. -
charset- Return the response’s charset. This function will allocate memory for the charset string and caller must release the string by OH_ArkWeb_ReleaseString.
Required System Capabilities: SystemCapability.Web.Webview.Core
Available since API-level: 12