pub unsafe extern "C" fn OH_ArkWebResponse_GetHeaderByName(
response: *const ArkWeb_Response,
name: *const c_char,
value: *mut *mut c_char,
)Available on crate features
api-11 and api-12 only.Expand description
Get the header from the response.
Arguments
-
response- The ArkWeb_Response. -
name- The name of the header. -
value- Return the header’s value. This function will allocate memory for the value string and caller must release the string by OH_ArkWeb_ReleaseString.
Required System Capabilities: SystemCapability.Web.Webview.Core
Available since API-level: 12