ArkWeb_CustomSchemeOption

Struct ArkWeb_CustomSchemeOption 

#[repr(transparent)]
pub struct ArkWeb_CustomSchemeOption(pub c_uint);
Available on crate features api-11 and api-12 only.
Configuration information for custom schemes.

Required System Capabilities: SystemCapability.Web.Webview.Core

Available since API-level: 12

Tuple Fields

0: c_uint

Implementations

Source

impl ArkWeb_CustomSchemeOption

pub const OH_ARKWEB_SCHEME_OPTION_NONE: ArkWeb_CustomSchemeOption

pub const ARKWEB_SCHEME_OPTION_STANDARD: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_STANDARD is set, the scheme will be handled as a standard scheme. The standard schemes need to comply with the URL normalization and parsing rules defined in Section 3.1 of RFC 1738, which can be found in the http://www.ietf.org/rfc/rfc1738.txt.

pub const ARKWEB_SCHEME_OPTION_LOCAL: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_LOCAL is set, the same security rules as those applied to the “file” URL will be used to handle the scheme.

pub const ARKWEB_SCHEME_OPTION_DISPLAY_ISOLATED: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_DISPLAY_ISOLATED is set, then the scheme can only be displayed from other content hosted using the same scheme.

pub const ARKWEB_SCHEME_OPTION_SECURE: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_SECURE is set, the same security rules as those applied to the “https” URL will be used to handle the scheme.

pub const ARKWEB_SCHEME_OPTION_CORS_ENABLED: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_CORS_ENABLED is set, then the scheme can be sent CORS requests. In most cases this value should be set when ARKWEB_SCHEME_OPTION_STANDARD is set.

pub const ARKWEB_SCHEME_OPTION_CSP_BYPASSING: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_CSP_BYPASSING is set, then this scheme can bypass Content Security Policy (CSP) checks. In most cases, this value should not be set when ARKWEB_SCHEME_OPTION_STANDARD is set.

pub const ARKWEB_SCHEME_OPTION_FETCH_ENABLED: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_FETCH_ENABLED is set, then this scheme can perform FETCH API requests.

pub const ARKWEB_SCHEME_OPTION_CODE_CACHE_ENABLED: ArkWeb_CustomSchemeOption

If ARKWEB_SCHEME_OPTION_CODE_CACHE_ENABLED is set, then the js of this scheme can generate code cache.