Module arkweb_type

Module arkweb_type 

Available on crate features api-11 and api-12 only.

Structs

ArkWeb_ComponentAPI
Defines the component API for native ArkWeb.
ArkWeb_ControllerAPI
Defines the controller API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM.
ArkWeb_CookieManagerAPI
Defines the native CookieManager API for ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM.
ArkWeb_JavaScriptBridgeData
Defines the javascript bridge data type.
ArkWeb_JavaScriptObject
Defines the javascript object.
ArkWeb_JavaScriptValue
ArkWeb_JavaScriptValueAPIapi-18
Defines the native JavaScriptValue API for ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM.
ArkWeb_JavaScriptValueTypeapi-18
Defines the data type carried in a ArkWeb_JavaScriptValue.
ArkWeb_ProxyMethod
Defines the javascript proxy registered method object.
ArkWeb_ProxyMethodWithResultapi-18
Defines the JavaScript proxy method with a return value.
ArkWeb_ProxyObject
Defines the javascript proxy registered object.
ArkWeb_ProxyObjectWithResultapi-18
Defines the JavaScript proxy registered object with methodList that has a return value.
ArkWeb_WebMessage
ArkWeb_WebMessageAPI
Defines the web message data API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM.
ArkWeb_WebMessagePort
ArkWeb_WebMessagePortAPI
Defines the web message API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM.
ArkWeb_WebMessageType
Defines the data type carried in a ArkWeb_WebMessage.

Type Aliases

ArkWeb_JavaScriptValuePtrapi-18
Defines the ArkWeb_JavaScriptValuePtr.
ArkWeb_OnComponentCallback
Defines the component callback of the native ArkWeb.
ArkWeb_OnJavaScriptCallback
Defines the javascript callback of the native ArkWeb.
ArkWeb_OnJavaScriptProxyCallback
Defines the javascript proxy callback of the native ArkWeb.
ArkWeb_OnJavaScriptProxyCallbackWithResultapi-18
Defines the JavaScript proxy callback of the native ArkWeb.
ArkWeb_OnMessageEventHandler
Defines the callback to receive message from HTML.
ArkWeb_OnScrollCallbackapi-18
Defines the scroll callback of the native ArkWeb.
ArkWeb_WebMessagePortPtr
Defines the ArkWeb_WebMessagePort that represent a HTML5 message port.
ArkWeb_WebMessagePtr
Defines the ArkWeb_WebMessage.