ArkWeb_JavaScriptValueAPI

Struct ArkWeb_JavaScriptValueAPI 

#[repr(C)]
pub struct ArkWeb_JavaScriptValueAPI { pub size: usize, pub createJavaScriptValue: Option<unsafe extern "C" fn(type_: ArkWeb_JavaScriptValueType, data: *mut c_void, dataLength: usize) -> ArkWeb_JavaScriptValuePtr>, }
Available on crate features api-11 and api-12 and api-18 only.
Defines the native JavaScriptValue API for ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM.

Available since API-level: 18

Fields

size: usize

The ArkWeb_JavaScriptValueAPI struct size.

createJavaScriptValue: Option<unsafe extern "C" fn(type_: ArkWeb_JavaScriptValueType, data: *mut c_void, dataLength: usize) -> ArkWeb_JavaScriptValuePtr>

Create the JavaScript value responding to HTML.

Arguments

  • type - The type of ArkWeb_JavaScriptValue.

  • data - The data buffer of ArkWeb_JavaScriptValue.

  • dataLength - The length of data buffer.

Returns

  • ArkWeb_JavaScriptValuePtr created by ArkWeb, the memory of ArkWeb_JavaScriptValue is managed by ArkWeb itself.