ArkWeb_WebMessageAPI

Struct ArkWeb_WebMessageAPI 

#[repr(C)]
pub struct ArkWeb_WebMessageAPI { pub size: usize, pub createWebMessage: Option<unsafe extern "C" fn() -> ArkWeb_WebMessagePtr>, pub destroyWebMessage: Option<unsafe extern "C" fn(webMessage: *mut ArkWeb_WebMessagePtr)>, pub setType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, type_: ArkWeb_WebMessageType)>, pub getType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr) -> ArkWeb_WebMessageType>, pub setData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, data: *mut c_void, dataLength: usize)>, pub getData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, dataLength: *mut usize) -> *mut c_void>, }
Available on crate features api-11 and api-12 only.
Defines the web message data API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM.

Available since API-level: 12

Fields

size: usize

The ArkWeb_WebMessageAPI struct size.

createWebMessage: Option<unsafe extern "C" fn() -> ArkWeb_WebMessagePtr>

Used to create a ArkWeb_WebMessage.

Returns

  • The created ArkWeb_WebMessage, destroy it through destroyWebMessage after it is no longer used.
destroyWebMessage: Option<unsafe extern "C" fn(webMessage: *mut ArkWeb_WebMessagePtr)>

Used to destroy a ArkWeb_WebMessage.

Arguments

  • webMessage - The ArkWeb_WebMessage to destroy.
setType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, type_: ArkWeb_WebMessageType)>

Set the type of ArkWeb_WebMessage.

Arguments

  • webMessage - The ArkWeb_WebMessage.

  • type - The type of ArkWeb_WebMessage.

getType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr) -> ArkWeb_WebMessageType>

Get the type of ArkWeb_WebMessage.

Arguments

  • webMessage - The ArkWeb_WebMessage.

Returns

  • The type of ArkWeb_WebMessage.
setData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, data: *mut c_void, dataLength: usize)>

Set the data of ArkWeb_WebMessage.

Arguments

  • webMessage - The ArkWeb_WebMessage.

  • data - The data of ArkWeb_WebMessage.

  • dataLength - The length of data.

getData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, dataLength: *mut usize) -> *mut c_void>

Get the data of ArkWeb_WebMessage.

Arguments

  • webMessage - The ArkWeb_WebMessage.

  • dataLength - The length of data.

Returns

  • The data of ArkWeb_WebMessage.