Available on crate feature
api-11 only.Structs
- ArkWeb
Engine Version api-20 - ArkWeb Engine Version.
- ArkWeb_
Blankless Info api-20 - Defines the blankless information.
Functions
- OH_
ArkWeb ⚠Cookie Manager_ Save Cookie Async api-20 - Ensure that all cookies currently accessible via the CookieManager API have been persisted to disk. Without initializing the CookieManager interface, this call will automatically be executed on the UI thread.
- OH_
ArkWeb ⚠Cookie Manager_ Save Cookie Sync api-20 - Ensure that all cookies currently accessible via the CookieManager API have been persisted to disk. If you want to use this interface in a non-UI thread, you need to initialize the CookieManager interface using OH_ArkWeb_GetNativeAPI first.
- OH_
Native ⚠ArkWeb_ Clear Blankless Loading Cache api-20 - Clears the blankless loading cache of the page with a specified key value.
- OH_
Native ⚠ArkWeb_ GetActive WebEngine Version api-20 - Get currently active ArkWeb engine version.
- OH_
Native ⚠ArkWeb_ GetBlankless Info With Key api-20 - Obtains the prediction information about the blankless loading solution and enables the generation of the transition frame for the current loading. The application determines whether to enable the blankless loading solution based on the information. This API applies to pages in an applet or web application whose URLs are not fixed or cannot be uniquely identified.
- OH_
Native ⚠ArkWeb_ GetDestroy Callback - Get the destroy callback.
- OH_
Native ⚠ArkWeb_ GetJava Script Proxy Valid Callback - Get the valid callback.
- OH_
Native ⚠ArkWeb_ Load Data api-15 - Loads the data or URL. This function should be called on main thread.
- OH_
Native ⚠ArkWeb_ Register Async Thread Java Script Proxy api-20 - Registers a JavaScript object with callback methods, which may return values. This object will be injected into all frames of the current page, including all iframes, and will be accessible using the specified name in ArkWeb_ProxyObjectWithResult. The object will only be available in JavaScript after the next load or reload. These methods will be executed in the ArkWeb worker thread.
- OH_
Native ⚠ArkWeb_ Register Java Script Proxy - Registers the JavaScript object and method list.
- OH_
Native ⚠ArkWeb_ RunJava Script - Loads a piece of code and execute JS code in the context of the currently displayed page.
- OH_
Native ⚠ArkWeb_ SetActive WebEngine Version api-20 - Set active ArkWeb engine version. If the system does not support the specified version, it will not take effect.
- OH_
Native ⚠ArkWeb_ SetBlankless Loading Cache Capacity api-20 - Sets the cache capacity of the blankless loading solution and returns the value that takes effect.
- OH_
Native ⚠ArkWeb_ SetBlankless Loading With Key api-20 - Sets whether to enable blankless page loading. This API must be used in pair with the OH_NativeArkWeb_GetBlanklessInfoWithKey API.
- OH_
Native ⚠ArkWeb_ SetDestroy Callback - Registers the destroy callback.
- OH_
Native ⚠ArkWeb_ SetJava Script Proxy Valid Callback - Registers the valid callback.
- OH_
Native ⚠ArkWeb_ Unregister Java Script Proxy - Deletes the registered object which th given name.
Type Aliases
- Native
ArkWeb_ OnDestroy Callback - Defines the destroy callback of the web component.
- Native
ArkWeb_ OnJava Script Callback - Defines the javascript callback of the web component.
- Native
ArkWeb_ OnJava Script Proxy Callback - Defines the javascript proxy callback of the web component.
- Native
ArkWeb_ OnValid Callback - Defines the valid callback of the web component.
- OH_
ArkWeb_ OnCookie Save Callback api-20 - Defines the callback of save cookie.