OH_ArkWebCookieManager_SaveCookieAsync

Function OH_ArkWebCookieManager_SaveCookieAsync 

pub unsafe extern "C" fn OH_ArkWebCookieManager_SaveCookieAsync(
    callback: OH_ArkWeb_OnCookieSaveCallback,
)
Available on crate feature api-20 only.
Ensure that all cookies currently accessible via the CookieManager API have been persisted to disk. Without initializing the CookieManager interface, this call will automatically be executed on the UI thread.

Arguments

  • callback - Callback execute when save cookie done.

Available since API-level: 20