OH_ArkWebCookieManager_SaveCookieSync

Function OH_ArkWebCookieManager_SaveCookieSync 

pub unsafe extern "C" fn OH_ArkWebCookieManager_SaveCookieSync() -> ArkWeb_ErrorCode
Available on crate feature api-20 only.
Ensure that all cookies currently accessible via the CookieManager API have been persisted to disk. If you want to use this interface in a non-UI thread, you need to initialize the CookieManager interface using OH_ArkWeb_GetNativeAPI first.

Returns

  • Save cookie result code. [ARKWEB_SUCCESS] Save cookie success. [ARKWEB_COOKIE_SAVE_FAILED] Save cookie failed. [ARKWEB_COOKIE_MANAGER_INITIALIZE_FAILED] The CookieManager initialize failed. [ARKWEB_COOKIE_MANAGER_NOT_INITIALIZED] It is not allowed to call on a non-UI thread without initializing the CookieManager interface. please initialize the CookieManager interface using OH_ArkWeb_GetNativeAPI first.

Available since API-level: 20