OH_NativeArkWeb_GetJavaScriptProxyValidCallback

Function OH_NativeArkWeb_GetJavaScriptProxyValidCallback 

pub unsafe extern "C" fn OH_NativeArkWeb_GetJavaScriptProxyValidCallback(
    webTag: *const c_char,
) -> NativeArkWeb_OnValidCallback
Available on crate feature api-11 only.
Get the valid callback.

Arguments

  • webTag - The name of the web component.

Returns

  • Return the valid callback function registered. If the valid callback function specified by the parameter webTag is not set, a null pointer is returned.

Required System Capabilities: SystemCapability.Web.Webview.Core

Available since API-level: 11