OH_NativeArkWeb_SetActiveWebEngineVersion

Function OH_NativeArkWeb_SetActiveWebEngineVersion 

pub unsafe extern "C" fn OH_NativeArkWeb_SetActiveWebEngineVersion(
    webEngineVersion: ArkWebEngineVersion,
)
Available on crate feature api-20 only.
Set active ArkWeb engine version. If the system does not support the specified version, it will not take effect.

This is a global static API that must be called before initializeWebEngine, and it will have no effect if any Web components are loaded.

Legacy Web Engine Compatibility Note:

When using legacy ArkWeb Engine, some ArkWeb newly created API will not take effect,
see [Compatible with Legacy Web Engine in release note] for compatibility guidelines.

Arguments

{ ArkWebEngineVersion } webEngineVersion - the ArkWebEngineVersion

Available since API-level: 20