OH_NativeArkWeb_SetBlanklessLoadingCacheCapacity

Function OH_NativeArkWeb_SetBlanklessLoadingCacheCapacity 

pub unsafe extern "C" fn OH_NativeArkWeb_SetBlanklessLoadingCacheCapacity(
    capacity: u32,
) -> u32
Available on crate feature api-20 only.
Sets the cache capacity of the blankless loading solution and returns the value that takes effect.

Arguments

  • capacity - Cache capacity, in MB. The maximum value is 100 MB. The default value is 30 MB. The value ranges from 0 to 100. If this parameter is set to 0, no cache capacity is available and the functionality is disabled globally. When the value is set to a number smaller than 0, the value 0 takes effect. When the value is set to a number greater than 100, the value 100 takes effect.

Returns

  • The effective value that ranges from 0 MB to 100 MB.

Available since API-level: 20