pub unsafe extern "C" fn OH_NativeArkWeb_SetBlanklessLoadingWithKey(
webTag: *const c_char,
key: *const c_char,
isStarted: bool,
) -> ArkWeb_BlanklessErrorCodeAvailable on crate feature
api-20 only.Expand description
Sets whether to enable blankless page loading. This API must be used in pair with the OH_NativeArkWeb_GetBlanklessInfoWithKey API.
Arguments
-
webTag- webTag used when the webviewController is created. -
key- Key value that uniquely identifies the current page. It must be the same as the key value of the OH_NativeArkWeb_GetBlanklessInfoWithKey API. -
isStarted- Whether to enable frame interpolation. The value true indicates to enable frame interpolation, and the value false indicates the opposite. The default value is false. The value can be true or false. Action for setting an invalid value: N/A.
Returns
- Whether the API is successfully called. For details, see ArkWeb_BlanklessErrorCode.
Available since API-level: 20