Available on crate features
api-11 and api-12 only.Structs
- ArkWeb_
Custom Scheme Option - Configuration information for custom schemes.
- ArkWeb_
Http Body Stream_ - ArkWeb_
Request Header List_ - ArkWeb_
Resource Handler_ - ArkWeb_
Resource Request_ - ArkWeb_
Resource Type - Resource type for a request.
- ArkWeb_
Response_ - ArkWeb_
Scheme Handler_
Functions
- OH_
ArkWeb ⚠Http Body Stream_ Async Read api-20 - Read the http body to the buffer.
- OH_
ArkWeb ⚠Http Body Stream_ GetPosition - Get the current position of the data stream.
- OH_
ArkWeb ⚠Http Body Stream_ GetSize - Get the total size of the data stream.
- OH_
ArkWeb ⚠Http Body Stream_ GetUser Data - Get the user data from ArkWeb_HttpBodyStream.
- OH_
ArkWeb ⚠Http Body Stream_ Init - Init the http body stream.
- OH_
ArkWeb ⚠Http Body Stream_ IsChunked - Get if the data stream is chunked.
- OH_
ArkWeb ⚠Http Body Stream_ IsEof - Returns true if all data has been consumed from this upload data stream.
- OH_
ArkWeb ⚠Http Body Stream_ IsIn Memory - Returns true if the upload data in the stream is entirely in memory, and all read requests will succeed synchronously.
- OH_
ArkWeb ⚠Http Body Stream_ Read - Read the http body to the buffer.
- OH_
ArkWeb ⚠Http Body Stream_ SetAsync Read Callback api-20 - Set the callback for OH_ArkWebHttpBodyStream_AsyncRead.
- OH_
ArkWeb ⚠Http Body Stream_ SetRead Callback - Set the callback for OH_ArkWebHttpBodyStream_Read.
- OH_
ArkWeb ⚠Http Body Stream_ SetUser Data - Set a user data to ArkWeb_HttpBodyStream.
- OH_
ArkWeb ⚠Request Header List_ Destroy - Destroy the ArkWeb_RequestHeaderList.
- OH_
ArkWeb ⚠Request Header List_ GetHeader - Get the specified request header.
- OH_
ArkWeb ⚠Request Header List_ GetSize - Get the request headers size.
- OH_
ArkWeb ⚠Resource Handler_ Destroy - Destroy the ArkWeb_ResourceHandler.
- OH_
ArkWeb ⚠Resource Handler_ DidFail With Error - Notify the ArkWeb that this request should be failed.
- OH_
ArkWeb ⚠Resource Handler_ DidFail With Error V2 api-20 - Notify the ArkWeb that this request should be failed.
- OH_
ArkWeb ⚠Resource Handler_ DidFinish - Notify the ArkWeb that this request should be finished and there is no more data available.
- OH_
ArkWeb ⚠Resource Handler_ DidReceive Data - Pass response body data to intercepted requests.
- OH_
ArkWeb ⚠Resource Handler_ DidReceive Response - Pass response headers to intercepted requests.
- OH_
ArkWeb ⚠Resource Request_ Destroy - Destroy the ArkWeb_ResourceRequest.
- OH_
ArkWeb ⚠Resource Request_ Destroy Http Body Stream - Destroy the http body stream.
- OH_
ArkWeb ⚠Resource Request_ GetFrame Url - Get the url of frame which trigger this request.
- OH_
ArkWeb ⚠Resource Request_ GetHttp Body Stream - Create a ArkWeb_HttpBodyStream which used to read the http body.
- OH_
ArkWeb ⚠Resource Request_ GetMethod - Get the method of request.
- OH_
ArkWeb ⚠Resource Request_ GetReferrer - Get the referrer of request.
- OH_
ArkWeb ⚠Resource Request_ GetRequest Headers - Get the OH_ArkWeb_RequestHeaderList of the request.
- OH_
ArkWeb ⚠Resource Request_ GetResource Type - Get the resource type of request.
- OH_
ArkWeb ⚠Resource Request_ GetUrl - Get the url of request.
- OH_
ArkWeb ⚠Resource Request_ GetUser Data - Get the user data from ArkWeb_ResourceRequest.
- OH_
ArkWeb ⚠Resource Request_ HasGesture - Get if this is a request is triggered by user gesutre.
- OH_
ArkWeb ⚠Resource Request_ IsMain Frame - Get if this is a request from main frame.
- OH_
ArkWeb ⚠Resource Request_ IsRedirect - Get if this is a redirect request.
- OH_
ArkWeb ⚠Resource Request_ SetUser Data - Set a user data to ArkWeb_ResourceRequest.
- OH_
ArkWeb ⚠Response_ GetCharset - Get the response’s charset.
- OH_
ArkWeb ⚠Response_ GetError - Get the response’s error code.
- OH_
ArkWeb ⚠Response_ GetHeader ByName - Get the header from the response.
- OH_
ArkWeb ⚠Response_ GetMime Type - Get the response’s mime type.
- OH_
ArkWeb ⚠Response_ GetStatus - Get the response’s status code.
- OH_
ArkWeb ⚠Response_ GetStatus Text - Get the response’s status text.
- OH_
ArkWeb ⚠Response_ GetUrl - Get the resolved URL after redirects or changed as a result of HSTS.
- OH_
ArkWeb ⚠Response_ SetCharset - Set charset to ArkWeb_Response.
- OH_
ArkWeb ⚠Response_ SetError - Set a error code to ArkWeb_Response.
- OH_
ArkWeb ⚠Response_ SetHeader ByName - Set a header to ArkWeb_Response.
- OH_
ArkWeb ⚠Response_ SetMime Type - Set mime type to ArkWebResponse.
- OH_
ArkWeb ⚠Response_ SetStatus - Set a status code to ArkWebResponse.
- OH_
ArkWeb ⚠Response_ SetStatus Text - Set a status text to ArkWebResponse.
- OH_
ArkWeb ⚠Response_ SetUrl - Set the resolved URL after redirects or changed as a result of HSTS.
- OH_
ArkWeb ⚠Scheme Handler_ GetUser Data - Get the user data from ArkWeb_SchemeHandler.
- OH_
ArkWeb ⚠Scheme Handler_ SetOn Request Start - Set the OnRequestStart callback for SchemeHandler.
- OH_
ArkWeb ⚠Scheme Handler_ SetOn Request Stop - Set the OnRequestStop callback for SchemeHandler.
- OH_
ArkWeb ⚠Scheme Handler_ SetUser Data - Set a user data to ArkWeb_SchemeHandler.
- OH_
ArkWeb ⚠Service Worker_ Clear Scheme Handlers - Clear the handler registered on the specified web for service worker.
- OH_
ArkWeb ⚠Service Worker_ SetScheme Handler - Set a ArkWeb_SchemeHandler for a specific scheme to intercept requests of that scheme type.
- OH_
ArkWeb_ ⚠Clear Scheme Handlers - Clear the handler registered on the specified web.
- OH_
ArkWeb_ ⚠Create Response - Create a Response for a request.
- OH_
ArkWeb_ ⚠Create Scheme Handler - Create a SchemeHandler.
- OH_
ArkWeb_ ⚠Destroy Response - Destroy the Reponse.
- OH_
ArkWeb_ ⚠Destroy Scheme Handler - Destroy a SchemeHandler.
- OH_
ArkWeb_ ⚠Register Custom Schemes - Register custom scheme to the ArkWeb.
- OH_
ArkWeb_ ⚠Release Byte Array - Release the byte array acquired by native function.
- OH_
ArkWeb_ ⚠Release String - Release the string acquired by native function.
- OH_
ArkWeb_ ⚠SetScheme Handler - Set a ArkWeb_SchemeHandler for a specific scheme to intercept requests of that scheme type.
Type Aliases
- ArkWeb_
Http Body Stream - The http body of the request.
- ArkWeb_
Http Body Stream Async Read Callback api-20 - Callback when the read operation done.
- ArkWeb_
Http Body Stream Init Callback - Callback when the init operation done.
- ArkWeb_
Http Body Stream Read Callback - Callback when the read operation done.
- ArkWeb_
OnRequest Start - Callback for handling the request.
- ArkWeb_
OnRequest Stop - Callback when the request is completed.
- ArkWeb_
Request Header List - The request headers of the request.
- ArkWeb_
Resource Handler - Used to intercept url requests.
- ArkWeb_
Resource Request - The info of the request.
- ArkWeb_
Response - The response of the intercepted request.
- ArkWeb_
Scheme Handler - This class is used to intercept requests for a specified scheme.