pub unsafe extern "C" fn OH_ArkWebHttpBodyStream_IsEof(
httpBodyStream: *const ArkWeb_HttpBodyStream,
) -> boolAvailable on crate features
api-11 and api-12 only.Expand description
Returns true if all data has been consumed from this upload data stream.
For chunked uploads, returns false until the first read attempt.
Arguments
httpBodyStream- The ArkWeb_HttpBodyStream.
Returns
- True if all data has been consumed; false otherwise.
Required System Capabilities: SystemCapability.Web.Webview.Core
Available since API-level: 12