pub unsafe extern "C" fn OH_ArkWebHttpBodyStream_IsInMemory(
httpBodyStream: *const ArkWeb_HttpBodyStream,
) -> boolAvailable on crate features
api-11 and api-12 only.Expand description
Returns true if the upload data in the stream is entirely in memory, and all read requests will succeed synchronously.
Expected to return false for chunked requests.
Arguments
httpBodyStream- The ArkWeb_HttpBodyStream.
Returns
- True if the upload data is in memory; false otherwise.
Required System Capabilities: SystemCapability.Web.Webview.Core
Available since API-level: 12