OH_ArkWebResourceRequest_GetFrameUrl

Function OH_ArkWebResourceRequest_GetFrameUrl 

pub unsafe extern "C" fn OH_ArkWebResourceRequest_GetFrameUrl(
    resourceRequest: *const ArkWeb_ResourceRequest,
    frameUrl: *mut *mut c_char,
)
Available on crate features api-11 and api-12 only.
Get the url of frame which trigger this request.

Arguments

  • resourceRequest - The ArkWeb_ResourceRequest.

  • frameUrl - The url of frame which trigger this request. This function will allocate memory for the url string and caller must release the string by OH_ArkWeb_ReleaseString.

Required System Capabilities: SystemCapability.Web.Webview.Core

Available since API-level: 12