Module native_interface_arkweb

Module native_interface_arkweb 

Available on crate feature api-11 only.

Structs

ArkWebEngineVersionapi-20
ArkWeb Engine Version.
ArkWeb_BlanklessInfoapi-20
Defines the blankless information.

Functions

OH_ArkWebCookieManager_SaveCookieAsyncapi-20
Ensure that all cookies currently accessible via the CookieManager API have been persisted to disk. Without initializing the CookieManager interface, this call will automatically be executed on the UI thread.
OH_ArkWebCookieManager_SaveCookieSyncapi-20
Ensure that all cookies currently accessible via the CookieManager API have been persisted to disk. If you want to use this interface in a non-UI thread, you need to initialize the CookieManager interface using OH_ArkWeb_GetNativeAPI first.
OH_NativeArkWeb_ClearBlanklessLoadingCacheapi-20
Clears the blankless loading cache of the page with a specified key value.
OH_NativeArkWeb_GetActiveWebEngineVersionapi-20
Get currently active ArkWeb engine version.
OH_NativeArkWeb_GetBlanklessInfoWithKeyapi-20
Obtains the prediction information about the blankless loading solution and enables the generation of the transition frame for the current loading. The application determines whether to enable the blankless loading solution based on the information. This API applies to pages in an applet or web application whose URLs are not fixed or cannot be uniquely identified.
OH_NativeArkWeb_GetDestroyCallback
Get the destroy callback.
OH_NativeArkWeb_GetJavaScriptProxyValidCallback
Get the valid callback.
OH_NativeArkWeb_LoadDataapi-15
Loads the data or URL. This function should be called on main thread.
OH_NativeArkWeb_RegisterAsyncThreadJavaScriptProxyapi-20
Registers a JavaScript object with callback methods, which may return values. This object will be injected into all frames of the current page, including all iframes, and will be accessible using the specified name in ArkWeb_ProxyObjectWithResult. The object will only be available in JavaScript after the next load or reload. These methods will be executed in the ArkWeb worker thread.
OH_NativeArkWeb_RegisterJavaScriptProxy
Registers the JavaScript object and method list.
OH_NativeArkWeb_RunJavaScript
Loads a piece of code and execute JS code in the context of the currently displayed page.
OH_NativeArkWeb_SetActiveWebEngineVersionapi-20
Set active ArkWeb engine version. If the system does not support the specified version, it will not take effect.
OH_NativeArkWeb_SetBlanklessLoadingCacheCapacityapi-20
Sets the cache capacity of the blankless loading solution and returns the value that takes effect.
OH_NativeArkWeb_SetBlanklessLoadingWithKeyapi-20
Sets whether to enable blankless page loading. This API must be used in pair with the OH_NativeArkWeb_GetBlanklessInfoWithKey API.
OH_NativeArkWeb_SetDestroyCallback
Registers the destroy callback.
OH_NativeArkWeb_SetJavaScriptProxyValidCallback
Registers the valid callback.
OH_NativeArkWeb_UnregisterJavaScriptProxy
Deletes the registered object which th given name.

Type Aliases

NativeArkWeb_OnDestroyCallback
Defines the destroy callback of the web component.
NativeArkWeb_OnJavaScriptCallback
Defines the javascript callback of the web component.
NativeArkWeb_OnJavaScriptProxyCallback
Defines the javascript proxy callback of the web component.
NativeArkWeb_OnValidCallback
Defines the valid callback of the web component.
OH_ArkWeb_OnCookieSaveCallbackapi-20
Defines the callback of save cookie.