OH_NativeArkWeb_ClearBlanklessLoadingCache

Function OH_NativeArkWeb_ClearBlanklessLoadingCache 

pub unsafe extern "C" fn OH_NativeArkWeb_ClearBlanklessLoadingCache(
    key: *mut *const c_char,
    size: u32,
)
Available on crate feature api-20 only.
Clears the blankless loading cache of the page with a specified key value.

Arguments

  • key - The list of key values of pages cached in the blankless loading solution. These key values are specified in OH_NativeArkWeb_GetBlanklessInfoWithKey. The default value is the list of key values of all pages cached in the blankless loading solution. The key length cannot exceed 2048 characters, and the number of keys must be less than or equal to 100. The URL is the same as that input to the Web component during page loading. When the key length exceeds 2048 characters, the key does not take effect. When the number of keys exceeds 100, the first 100 keys are used. If this parameter is set to NULL, the default value is used.

  • size - Size of the key list.

Available since API-level: 20