pub unsafe extern "C" fn OH_NativeArkWeb_GetBlanklessInfoWithKey(
webTag: *const c_char,
key: *const c_char,
) -> ArkWeb_BlanklessInfoAvailable on crate feature
api-20 only.Expand description
Obtains the prediction information about the blankless loading solution and enables the generation of the transition frame for the current loading. The application determines whether to enable the blankless loading solution based on the information. This API applies to pages in an applet or web application whose URLs are not fixed or cannot be uniquely identified.
Arguments
-
webTag- webTag used when the webviewController is created. Default value: N/A. The value cannot be empty. When an invalid value is set, the error code is returned, and the API does not take effect. -
key- Key value that uniquely identifies the current page.
Returns
- Return value of the ArkWeb_BlanklessInfo type.
Available since API-level: 20