OH_NativeArkWeb_GetDestroyCallback

Function OH_NativeArkWeb_GetDestroyCallback 

pub unsafe extern "C" fn OH_NativeArkWeb_GetDestroyCallback(
    webTag: *const c_char,
) -> NativeArkWeb_OnDestroyCallback
Available on crate feature api-11 only.
Get the destroy callback.

Arguments

  • webTag - The name of the web component.

Returns

  • Return the destroy callback function registered. If the destroy callback function specified by the parameter webTag is not set, a null pointer is returned.

Required System Capabilities: SystemCapability.Web.Webview.Core

Available since API-level: 11