OH_NativeArkWeb_LazyInitializeWebEngineInCookieManager

Function OH_NativeArkWeb_LazyInitializeWebEngineInCookieManager 

pub unsafe extern "C" fn OH_NativeArkWeb_LazyInitializeWebEngineInCookieManager(
    lazy: bool,
)
Available on crate feature api-22 only.
Delays the initialization of the web engine. By default, the web engine is initialized when the CookieManager interface is called. By setting the ‘lazy’ parameter to true, the web engine will not be initialized when the CookieManager interface is called. Instead, the web engine will be initialized either when the web component is created or when initializeWebEngine is called.

Arguments

{ bool } lazy - Controls whether to delay the initialization of the web engine.

Available since API-level: 22